@@ -449,7 +449,7 @@ static unsigned int_idle_0_rep; ///< Seconds before the second 0 event.
 static unsigned int_idle_1; ///< Seconds before the first 1 event.
 static unsigned int_idle_1_rep; ///< Seconds before the second 1 event.
 static unsigned int_idle_2; ///< Seconds before the first 2 event.
-static time_t int_idle_time_current; ///< Last time check in idle.
+static target_clock_t int_idle_time_current; ///< Last time check in idle.
 static bool int_idle_0_state; ///< Idle event 0 enabler.
 static bool int_idle_1_state; ///< Idle event 1 enabler.
 static bool int_idle_2_state; ///< Idle event 2 enabler.
@@ -691,7 +691,7 @@ void int_done()
 
 bool int_set(double gamma, double brightness, unsigned idle_0, unsigned idle_0_rep, unsigned idle_1, unsigned idle_1_rep, bool backdrop_fast, unsigned translucency, bool disable_special, bool auto_calib)
 {
-	int_idle_time_current = time(0);
+	int_idle_time_current = target_clock() / 1000000;
 	int_idle_0 = idle_0;
 	int_idle_1 = idle_1;
 	int_idle_0_rep = idle_0_rep;
@@ -1087,13 +1087,9 @@ void cell_pos_t::compute_size(unsigned* rx, unsigned* ry, const adv_bitmap* bitm
 	}
 
 	if (!aspectx || !aspecty) {
-		aspectx = bitmap->size_x;
-		aspecty = bitmap->size_y;
-	}
-
-	if (!aspectx || !aspecty) {
-		aspectx = 1;
-		aspecty = 1;
+		*rx = real_dx;
+		*ry = real_dy;
+		return;
 	}
 
 	aspectx *= 3 * video_size_x();
@@ -2829,8 +2825,8 @@ void int_clear_alpha(int x, int y, int dx, int dy, const adv_color_rgb& color)
 
 bool int_clip(const string& file, bool loop)
 {
-	unsigned aspectx = int_dx_get();
-	unsigned aspecty = int_dy_get();
+	unsigned aspectx = 0; // 0 stretch the bitmap to fill all the screen
+	unsigned aspecty = 0;
 	resource res = path_import(file);
 
 	bool wait = true;
@@ -3093,7 +3089,7 @@ static void input_poll()
 
 void int_idle_time_reset()
 {
-	int_idle_time_current = time(0);
+	int_idle_time_current = target_clock() / 1000000;
 	int_last = EVENT_NONE;
 }
 
@@ -3115,18 +3111,18 @@ void int_idle_2_enable(bool state, unsigned delay)
 
 static void int_idle()
 {
-	time_t now = time(0);
-	time_t elapsed = now - int_idle_time_current;
+	target_clock_t now = target_clock() / 1000000;
+	target_clock_t elapsed = now - int_idle_time_current;
 
 	if (int_idle_0_state) {
 		if (int_idle_0_rep != 0
 			&& int_last == EVENT_IDLE_0
-			&& elapsed > int_idle_0_rep
+			&& elapsed >= int_idle_0_rep
 		) {
 			log_std(("text: push IDLE_0 repeat\n"));
 			event_push_repeat(EVENT_IDLE_0);
 		} else if (int_idle_0 != 0
-			&& elapsed > int_idle_0
+			&& elapsed >= int_idle_0
 		) {
 			log_std(("text: push IDLE_0\n"));
 			event_push_repeat(EVENT_IDLE_0);
@@ -3136,12 +3132,12 @@ static void int_idle()
 	if (int_idle_1_state) {
 		if (int_idle_1_rep != 0
 			&& int_last == EVENT_IDLE_1
-			&& elapsed > int_idle_1_rep
+			&& elapsed >= int_idle_1_rep
 		) {
 			log_std(("text: push IDLE_1 repeat\n"));
 			event_push_repeat(EVENT_IDLE_1);
 		} else if (int_idle_1 != 0
-			&& elapsed > int_idle_1
+			&& elapsed >= int_idle_1
 		) {
 			log_std(("text: push IDLE_1\n"));
 			event_push_repeat(EVENT_IDLE_1);
@@ -3150,7 +3146,7 @@ static void int_idle()
 
 	if (int_idle_2_state) {
 		if (int_idle_2 != 0
-			&& elapsed > int_idle_2
+			&& elapsed >= int_idle_2
 		) {
 			log_std(("text: push IDLE_2\n"));
 			event_push_repeat(EVENT_IDLE_2);
@@ -3232,7 +3228,7 @@ bool int_event_waiting()
 
 	if (event_peek() != EVENT_NONE) {
 		// something happened, restart the timers
-		int_idle_time_current = time(0);
+		int_idle_time_current = target_clock() / 1000000;
 		joy_idle_time = now;
 		return 1;
 	}
