@@ -739,10 +739,6 @@ adv_error advance_fileio_init(struct advance_fileio_context* context, adv_conf*
 
 	context->state.diff_handle = 0;
 
-#ifdef MESS
-	conf_string_register_default(cfg_context, "dir_crc", file_config_dir_singledir("crc"));
-#endif
-
 	return 0;
 }
 
@@ -826,15 +822,6 @@ adv_error advance_fileio_config_load(struct advance_fileio_context* context, adv
 		}
 	}
 
-#ifdef MESS
-	{
-		const char* s = conf_string_get_default(cfg_context, "dir_crc");
-		const char* a = file_config_list(s, file_config_dir_singledir, 0);
-		log_std(("advance:fileio: %s %s\n", "dir_crc", a));
-		sncpy(option->crc_dir_buffer, sizeof(option->crc_dir_buffer), a);
-	}
-#endif
-
 	return 0;
 }
 
