@@ -1527,14 +1527,6 @@ static void video_buffer_clear(struct advance_video_context* context)
 	}
 }
 
-static unsigned pipeline_combine(unsigned p)
-{
-	if (p == 0)
-		return VIDEO_COMBINE_BUFFER;
-	else
-		return 0;
-}
-
 static void video_recompute_pipeline(struct advance_video_context* context, const struct osd_bitmap* bitmap)
 {
 	unsigned combine;
@@ -1709,12 +1701,11 @@ static void video_recompute_pipeline(struct advance_video_context* context, cons
 	}
 
 	combine_buffer = combine;
-	combine_video = combine;
+	combine_video = combine | context->config.combine_write;
 
 	free(context->state.buffer_ptr_alloc);
 
-	for (p = 0; p < PIPELINE_BLIT_MAX; ++p)
-		video_pipeline_init(&context->state.blit_pipeline[p]);
+	video_pipeline_init(&context->state.blit_pipeline);
 	video_pipeline_init(&context->state.buffer_pipeline_video);
 	context->state.blit_pipeline_flag = 1;
 
@@ -1733,20 +1724,17 @@ static void video_recompute_pipeline(struct advance_video_context* context, cons
 	video_pipeline_target(&context->state.buffer_pipeline_video, context->state.buffer_ptr, context->state.buffer_bytes_per_scanline, context->state.buffer_def);
 
 	if (context->state.game_rgb_flag) {
-		for (p = 0; p < PIPELINE_BLIT_MAX; ++p)
-			video_pipeline_direct(&context->state.blit_pipeline[p], context->state.mode_visible_size_x, context->state.mode_visible_size_y, context->state.game_visible_size_x, context->state.game_visible_size_y, context->state.blit_src_dw, context->state.blit_src_dp, context->state.game_color_def, combine_video | pipeline_combine(p));
+		video_pipeline_direct(&context->state.blit_pipeline, context->state.mode_visible_size_x, context->state.mode_visible_size_y, context->state.game_visible_size_x, context->state.game_visible_size_y, context->state.blit_src_dw, context->state.blit_src_dp, context->state.game_color_def, combine_video);
 		video_pipeline_direct(&context->state.buffer_pipeline_video, intermediate_mode_visible_size_x, intermediate_mode_visible_size_y, intermediate_game_visible_size_x, intermediate_game_visible_size_y, context->state.buffer_src_dw, context->state.buffer_src_dp, context->state.game_color_def, combine_buffer);
 	} else {
 		if (context->state.mode_index == MODE_FLAGS_INDEX_PALETTE8) {
 			assert(context->state.game_bytes_per_pixel == 2);
-			for (p = 0; p < PIPELINE_BLIT_MAX; ++p)
-				video_pipeline_palette16hw(&context->state.blit_pipeline[p], context->state.mode_visible_size_x, context->state.mode_visible_size_y, context->state.game_visible_size_x, context->state.game_visible_size_y, context->state.blit_src_dw, context->state.blit_src_dp, combine_video | pipeline_combine(p));
+			video_pipeline_palette16hw(&context->state.blit_pipeline, context->state.mode_visible_size_x, context->state.mode_visible_size_y, context->state.game_visible_size_x, context->state.game_visible_size_y, context->state.blit_src_dw, context->state.blit_src_dp, combine_video);
 			video_pipeline_palette16hw(&context->state.buffer_pipeline_video, intermediate_mode_visible_size_x, intermediate_mode_visible_size_y, intermediate_game_visible_size_x, intermediate_game_visible_size_y, context->state.buffer_src_dw, context->state.buffer_src_dp, combine_buffer);
 		} else {
 			switch (context->state.game_bytes_per_pixel) {
 			case 1:
-				for (p = 0; p < PIPELINE_BLIT_MAX; ++p)
-					video_pipeline_palette8(&context->state.blit_pipeline[p], context->state.mode_visible_size_x, context->state.mode_visible_size_y, context->state.game_visible_size_x, context->state.game_visible_size_y, context->state.blit_src_dw, context->state.blit_src_dp, context->state.palette_index8_map, context->state.palette_index16_map, context->state.palette_index32_map, combine_video | pipeline_combine(p));
+				video_pipeline_palette8(&context->state.blit_pipeline, context->state.mode_visible_size_x, context->state.mode_visible_size_y, context->state.game_visible_size_x, context->state.game_visible_size_y, context->state.blit_src_dw, context->state.blit_src_dp, context->state.palette_index8_map, context->state.palette_index16_map, context->state.palette_index32_map, combine_video);
 				/* use the alternate palette only if required */
 				if (context->state.buffer_def != video_color_def())
 					video_pipeline_palette8(&context->state.buffer_pipeline_video, intermediate_mode_visible_size_x, intermediate_mode_visible_size_y, intermediate_game_visible_size_x, intermediate_game_visible_size_y, context->state.buffer_src_dw, context->state.buffer_src_dp, context->state.buffer_index8_map, context->state.buffer_index16_map, context->state.buffer_index32_map, combine_buffer);
@@ -1754,8 +1742,7 @@ static void video_recompute_pipeline(struct advance_video_context* context, cons
 					video_pipeline_palette8(&context->state.buffer_pipeline_video, intermediate_mode_visible_size_x, intermediate_mode_visible_size_y, intermediate_game_visible_size_x, intermediate_game_visible_size_y, context->state.buffer_src_dw, context->state.buffer_src_dp, context->state.palette_index8_map, context->state.palette_index16_map, context->state.palette_index32_map, combine_buffer);
 				break;
 			case 2:
-				for (p = 0; p < PIPELINE_BLIT_MAX; ++p)
-					video_pipeline_palette16(&context->state.blit_pipeline[p], context->state.mode_visible_size_x, context->state.mode_visible_size_y, context->state.game_visible_size_x, context->state.game_visible_size_y, context->state.blit_src_dw, context->state.blit_src_dp, context->state.palette_index8_map, context->state.palette_index16_map, context->state.palette_index32_map, combine_video | pipeline_combine(p));
+				video_pipeline_palette16(&context->state.blit_pipeline, context->state.mode_visible_size_x, context->state.mode_visible_size_y, context->state.game_visible_size_x, context->state.game_visible_size_y, context->state.blit_src_dw, context->state.blit_src_dp, context->state.palette_index8_map, context->state.palette_index16_map, context->state.palette_index32_map, combine_video);
 				/* use the alternate palette only if required */
 				if (context->state.buffer_def != video_color_def())
 					video_pipeline_palette16(&context->state.buffer_pipeline_video, intermediate_mode_visible_size_x, intermediate_mode_visible_size_y, intermediate_game_visible_size_x, intermediate_game_visible_size_y, context->state.buffer_src_dw, context->state.buffer_src_dp, context->state.buffer_index8_map, context->state.buffer_index16_map, context->state.buffer_index32_map, combine_buffer);
@@ -1777,25 +1764,23 @@ static void video_recompute_pipeline(struct advance_video_context* context, cons
 
 		log_std(("emu:video: pipeline scale from %dx%d to %dx%d\n", context->state.game_visible_size_x, context->state.game_visible_size_y, context->state.mode_visible_size_x, context->state.mode_visible_size_y));
 
-		for (p = 0; p < PIPELINE_BLIT_MAX; ++p) {
-			log_std(("emu:video: pipeline_video %d\n", p));
-			for (i = 1, stage = video_pipeline_begin(&context->state.blit_pipeline[p]); stage != video_pipeline_end(&context->state.blit_pipeline[p]); ++stage, ++i) {
-				if (stage == video_pipeline_pivot(&context->state.blit_pipeline[p])) {
-					snprintf(buffer, sizeof(buffer), "(%d) %s", i, pipe_name(video_pipeline_vert(&context->state.blit_pipeline[p])->type));
-					++i;
-					log_std(("emu:video: %s\n", buffer));
-				}
-				if (stage->sbpp != stage->sdp)
-					snprintf(buffer, sizeof(buffer), "(%d) %s, p %d, dp %d", i, pipe_name(stage->type), stage->sbpp, stage->sdp);
-				else
-					snprintf(buffer, sizeof(buffer), "(%d) %s, p %d", i, pipe_name(stage->type), stage->sbpp);
-				log_std(("emu:video: %s\n", buffer));
-			}
-			if (stage == video_pipeline_pivot(&context->state.blit_pipeline[p])) {
-				snprintf(buffer, sizeof(buffer), "(%d) %s", i, pipe_name(video_pipeline_vert(&context->state.blit_pipeline[p])->type));
+		log_std(("emu:video: pipeline_video\n"));
+		for (i = 1, stage = video_pipeline_begin(&context->state.blit_pipeline); stage != video_pipeline_end(&context->state.blit_pipeline); ++stage, ++i) {
+			if (stage == video_pipeline_pivot(&context->state.blit_pipeline)) {
+				snprintf(buffer, sizeof(buffer), "(%d) %s", i, pipe_name(video_pipeline_vert(&context->state.blit_pipeline)->type));
 				++i;
 				log_std(("emu:video: %s\n", buffer));
 			}
+			if (stage->sbpp != stage->sdp)
+				snprintf(buffer, sizeof(buffer), "(%d) %s, p %d, dp %d", i, pipe_name(stage->type), stage->sbpp, stage->sdp);
+			else
+				snprintf(buffer, sizeof(buffer), "(%d) %s, p %d", i, pipe_name(stage->type), stage->sbpp);
+			log_std(("emu:video: %s\n", buffer));
+		}
+		if (stage == video_pipeline_pivot(&context->state.blit_pipeline)) {
+			snprintf(buffer, sizeof(buffer), "(%d) %s", i, pipe_name(video_pipeline_vert(&context->state.blit_pipeline)->type));
+			++i;
+			log_std(("emu:video: %s\n", buffer));
 		}
 
 		log_std(("emu:video: pipeline_buffer\n"));
@@ -1817,12 +1802,6 @@ static void video_recompute_pipeline(struct advance_video_context* context, cons
 			log_std(("emu:video: %s\n", buffer));
 		}
 	}
-
-	/* initialize the pipepeline measure */
-	context->state.pipeline_measure_flag = 1;
-	context->state.pipeline_measure_i = 0;
-	context->state.pipeline_measure_j = 0;
-	context->state.blit_pipeline_index = 0;
 }
 
 static void video_frame_put(struct advance_video_context* context, struct advance_ui_context* ui_context, const struct osd_bitmap* bitmap, unsigned x, unsigned y)
@@ -1962,7 +1941,7 @@ static void video_frame_put(struct advance_video_context* context, struct advanc
 		src_offset = context->state.blit_src_offset + context->state.game_visible_pos_y * context->state.blit_src_dw + context->state.game_visible_pos_x * context->state.blit_src_dp;
 
 		/* blit directly on the video */
-		video_pipeline_blit(&context->state.blit_pipeline[context->state.blit_pipeline_index], dst_x + x, dst_y + y, (unsigned char*)bitmap->ptr + src_offset);
+		video_pipeline_blit(&context->state.blit_pipeline, dst_x + x, dst_y + y, (unsigned char*)bitmap->ptr + src_offset);
 	}
 
 	/* no buffering is used */
@@ -1970,43 +1949,6 @@ static void video_frame_put(struct advance_video_context* context, struct advanc
 		/* end measure */
 		stop = target_clock() - start;
 
-		/* if we are in estimation phase */
-		if (context->state.pipeline_measure_flag) {
-
-			context->state.pipeline_measure_map[context->state.pipeline_measure_i][context->state.pipeline_measure_j] = stop;
-			++context->state.pipeline_measure_i;
-
-			if (context->state.pipeline_measure_i == PIPELINE_BLIT_MAX) {
-				context->state.pipeline_measure_i = 0;
-				++context->state.pipeline_measure_j;
-
-				if (context->state.pipeline_measure_j == PIPELINE_MEASURE_MAX) {
-					unsigned i;
-
-					for (i = 0; i < PIPELINE_BLIT_MAX; ++i) {
-						context->state.pipeline_measure_result[i] = adv_measure_median(0.00001, 0.5, context->state.pipeline_measure_map[i], PIPELINE_MEASURE_MAX);
-						log_std(("emu:video: pipeline %d -> time %g\n", i, context->state.pipeline_measure_result[i]));
-					}
-
-					context->state.pipeline_measure_i = 0;
-
-					/* The first one is selected, then next one is selected only if a 3% gain is measured */
-					for (i = 1; i < PIPELINE_BLIT_MAX; ++i) {
-						if (context->state.pipeline_measure_result[i] < 0.97 * context->state.pipeline_measure_result[context->state.pipeline_measure_i]) {
-							context->state.pipeline_measure_i = i;
-						}
-					}
-
-					log_std(("emu:video: best is %d\n", context->state.pipeline_measure_i));
-
-					/* end the measure process */
-					context->state.pipeline_measure_flag = 0;
-				}
-			}
-
-			context->state.blit_pipeline_index = context->state.pipeline_measure_i;
-		}
-
 		context->state.pipeline_timing_map[context->state.pipeline_timing_i] = stop;
 
 		++context->state.pipeline_timing_i;
