@@ -90,11 +90,6 @@ struct advance_glue_context {
 	const short* sound_current_buffer; /**< Last buffer of samples to play. */
 	unsigned sound_current_count; /**< Number of samples in the last buffer. */
 
-#ifdef MESS
-	char crc_file_buffer[MAME_MAXPATH]; /**< Storage for the the crcfile MESS pointer. */
-	char parent_crc_file_buffer[MAME_MAXPATH]; /**< Storage for the the pcrcfile MESS pointer. */
-#endif
-
 	char resolution_buffer[32]; /**< Buffer used by mame_resolution(). */
 	char resolutionclock_buffer[32]; /**< Buffer used by mame_resolutionclock(). */
 	char software_buffer[256]; /**< Buffer for software name. */
@@ -110,10 +105,6 @@ static struct advance_glue_context GLUE;
 /* MAME internal variables */
 extern char* cheatfile;
 extern const char *db_filename;
-#ifdef MESS
-const char* crcfile;
-const char* pcrcfile;
-#endif
 
 /**
  * Check if the game is working perfectly.
@@ -808,29 +799,6 @@ int mame_game_run(struct advance_context* context, const struct mame_option* adv
 	cheatfile = (char*)advance->cheat_file_buffer;
 	db_filename = advance->hiscore_file_buffer;
 
-#ifdef MESS
-	{
-		const game_driver* driver = (const game_driver*)context->game;
-		const game_driver* clone_of = driver_get_clone(driver);
-
-		snprintf(GLUE.crc_file_buffer, sizeof(GLUE.crc_file_buffer), "%s%c%s.crc", advance->crc_dir_buffer, file_dir_slash(), driver->name);
-		crcfile = GLUE.crc_file_buffer;
-
-		log_std(("glue: file_crc %s\n", crcfile));
-
-		if (clone_of
-			&& clone_of->name
-			&& (clone_of->flags & NOT_A_DRIVER) == 0) {
-			snprintf(GLUE.parent_crc_file_buffer, sizeof(GLUE.parent_crc_file_buffer), "%s%c%s.crc", advance->crc_dir_buffer, file_dir_slash(), clone_of->name);
-		} else {
-			GLUE.parent_crc_file_buffer[0] = 0;
-		}
-		pcrcfile = GLUE.parent_crc_file_buffer;
-
-		log_std(("glue: parent_file_crc %s\n", pcrcfile));
-	}
-#endif
-
 	for (game_index = 0; drivers[game_index]; ++game_index)
 		if ((const game_driver*)context->game == drivers[game_index])
 			break;
@@ -919,35 +887,48 @@ int mame_game_run(struct advance_context* context, const struct mame_option* adv
 #define K(name) \
 	{ "key_" name, "Key " name, { name } },
 
-#define KR1(name, re1) \
+#define O(name) \
+	{ "other_" name, "Other " name, { name } },
+
+#define O1(name, re1) \
+	{ "other_" name, "Other " name, { re1 } },
+
+#define O2(name, re1, re2) \
+	{ "other_" name, "Other " name, { re1, re2 } },
+
+#define O3(name, re1, re2, re3) \
+	{ "other_" name, "Other " name, { re1, re2, re3 } },
+
+#define K1(name, re1) \
 	{ "key_" name, "Key " name, { re1 } },
 
-#define KR2(name, re1, re2) \
+#define K2(name, re1, re2) \
 	{ "key_" name, "Key " name, { re1, re2 } },
 
-#define KR3(name, re1, re2, re3) \
+#define K3(name, re1, re2, re3) \
 	{ "key_" name, "Key " name, { re1, re2, re3 } },
 
-#define KR4(name, re1, re2, re3, re4) \
+#define K4(name, re1, re2, re3, re4) \
 	{ "key_" name, "Key " name, { re1, re2, re3, re4 } },
 
-#define KR5(name, re1, re2, re3, re4, re5) \
+#define K5(name, re1, re2, re3, re4, re5) \
 	{ "key_" name, "Key " name, { re1, re2, re3, re4, re5 } },
 
-#ifdef MESS
-struct glue_keyboard_name {
+struct glue_port_name {
 	const char* name;
 	char desc[64];
 	const char* glob[8];
 };
 
+
+#ifdef MESS
 /**
  * Keyboard name definitions.
  * This list defines some common names used in keyboards.
  * Note that the order of definition is relevant on the recognition of
  * the key from it's free form description on the MESS driver port list.
  */
-static struct glue_keyboard_name GLUE_KEYBOARD_STD[] = {
+static struct glue_port_name GLUE_KEYBOARD_STD[] = {
 
 	K("q")
 	K("w")
@@ -976,42 +957,42 @@ static struct glue_keyboard_name GLUE_KEYBOARD_STD[] = {
 	K("n")
 	K("m")
 
-	KR4("pad_0", "keypad*0", "0*keypad?", "0*kp?", "kp*0")
-	KR4("pad_1", "keypad*1", "1*keypad?", "1*kp?", "kp*1")
-	KR4("pad_2", "keypad*2", "2*keypad?", "2*kp?", "kp*2")
-	KR4("pad_3", "keypad*3", "3*keypad?", "3*kp?", "kp*3")
-	KR4("pad_4", "keypad*4", "4*keypad?", "4*kp?", "kp*4")
-	KR4("pad_5", "keypad*5", "5*keypad?", "5*kp?", "kp*5")
-	KR4("pad_6", "keypad*6", "6*keypad?", "6*kp?", "kp*6")
-	KR4("pad_7", "keypad*7", "7*keypad?", "7*kp?", "kp*7")
-	KR4("pad_8", "keypad*8", "8*keypad?", "8*kp?", "kp*8")
-	KR4("pad_9", "keypad*9", "9*keypad?", "9*kp?", "kp*9")
-	KR4("pad_enter", "keypad*enter", "enter*keypad?", "enter*kp?", "kp*enter")
-	KR4("pad_minus", "keypad*-", "-*keypad?", "-*kp?", "kp*-")
-	KR4("pad_plus", "keypad*+", "+*keypad?", "+*kp?", "kp*+")
-	KR4("pad_slash", "keypad*/", "/*keypad?", "/*kp?", "kp*/")
-	KR4("pad_colon", "keypad*.", ".*keypad?", ".*kp?", "kp*.")
-	KR4("pad_diesis", "keypad*#", "#*keypad?", "#*kp?", "kp*#")
-	KR4("pad_asterisk", "keypad*\\*", "\\**keypad?", "\\**kp?", "kp*\\*")
+	K4("pad_0", "keypad*0", "0*keypad?", "0*kp?", "kp*0")
+	K4("pad_1", "keypad*1", "1*keypad?", "1*kp?", "kp*1")
+	K4("pad_2", "keypad*2", "2*keypad?", "2*kp?", "kp*2")
+	K4("pad_3", "keypad*3", "3*keypad?", "3*kp?", "kp*3")
+	K4("pad_4", "keypad*4", "4*keypad?", "4*kp?", "kp*4")
+	K4("pad_5", "keypad*5", "5*keypad?", "5*kp?", "kp*5")
+	K4("pad_6", "keypad*6", "6*keypad?", "6*kp?", "kp*6")
+	K4("pad_7", "keypad*7", "7*keypad?", "7*kp?", "kp*7")
+	K4("pad_8", "keypad*8", "8*keypad?", "8*kp?", "kp*8")
+	K4("pad_9", "keypad*9", "9*keypad?", "9*kp?", "kp*9")
+	K4("pad_enter", "keypad*enter", "enter*keypad?", "enter*kp?", "kp*enter")
+	K4("pad_minus", "keypad*-", "-*keypad?", "-*kp?", "kp*-")
+	K4("pad_plus", "keypad*+", "+*keypad?", "+*kp?", "kp*+")
+	K4("pad_slash", "keypad*/", "/*keypad?", "/*kp?", "kp*/")
+	K4("pad_colon", "keypad*.", ".*keypad?", ".*kp?", "kp*.")
+	K4("pad_diesis", "keypad*#", "#*keypad?", "#*kp?", "kp*#")
+	K4("pad_asterisk", "keypad*\\*", "\\**keypad?", "\\**kp?", "kp*\\*")
 
-	KR1("0", "0")
-	KR1("1", "1")
-	KR1("2", "2")
-	KR1("3", "3")
-	KR1("4", "4")
-	KR1("5", "5")
-	KR1("6", "6")
-	KR1("7", "7")
-	KR1("8", "8")
-	KR1("9", "9")
+	K1("0", "0")
+	K1("1", "1")
+	K1("2", "2")
+	K1("3", "3")
+	K1("4", "4")
+	K1("5", "5")
+	K1("6", "6")
+	K1("7", "7")
+	K1("8", "8")
+	K1("9", "9")
 
-	KR2("esc", "esc", "escape")
-	KR2("enter", "enter", "return")
-	KR2("backspace", "back*space", "clr")
+	K2("esc", "esc", "escape")
+	K2("enter", "enter", "return")
+	K2("backspace", "back*space", "clr")
 	K("tab")
-	KR2("space", "space", "?space?")
-	KR2("ins", "ins", "insert")
-	KR2("del", "del", "delete")
+	K2("space", "space", "?space?")
+	K2("ins", "ins", "insert")
+	K2("del", "del", "delete")
 	K("home")
 	K("end")
 	K("fctn")
@@ -1022,7 +1003,7 @@ static struct glue_keyboard_name GLUE_KEYBOARD_STD[] = {
 	K("hold")
 	K("rew")
 	K("record")
-	KR2("break", "break", "brk")
+	K2("break", "break", "brk")
 	K("graph")
 	K("pause")
 	K("menu")
@@ -1039,48 +1020,48 @@ static struct glue_keyboard_name GLUE_KEYBOARD_STD[] = {
 	K("help")
 	K("back")
 	K("forward")
-	KR2("capslock", "caps*lock", "shift*lock")
-	KR1("scrlock", "scroll*lock")
-	KR1("numlock", "num*lock")
+	K2("capslock", "caps*lock", "shift*lock")
+	K1("scrlock", "scroll*lock")
+	K1("numlock", "num*lock")
 	K("quickload")
-	KR2("pgup", "pgup", "page*up")
-	KR2("pgdn", "pgdn", "page*down")
+	K2("pgup", "pgup", "page*up")
+	K2("pgdn", "pgdn", "page*down")
 
-	KR2("backquote", "backquote", "`")
-	KR2("minus", "minus", "-")
-	KR2("plus", "plus", "+")
-	KR2("asterisk", "asterisk", "\\*")
-	KR2("equals", "equals", "=")
-	KR2("openbrace", "openbrace", "(")
-	KR2("closebrace", "closebrace", ")")
-	KR2("semicolon", "semicolon", ";")
-	KR2("quote", "quote", "'")
-	KR2("backslash", "backslash", "\\\\")
-	KR2("less", "less", "<")
-	KR2("comma", "comma", ",")
-	KR2("period", "period", ".")
-	KR2("slash", "slash", "/")
-	KR2("colon", "colon", ":")
-	KR2("pound", "pound", "£")
-	KR2("doublequote", "doublequote", "\"")
-	KR2("diesis", "diessi", "#")
+	K2("backquote", "backquote", "`")
+	K2("minus", "minus", "-")
+	K2("plus", "plus", "+")
+	K2("asterisk", "asterisk", "\\*")
+	K2("equals", "equals", "=")
+	K2("openbrace", "openbrace", "(")
+	K2("closebrace", "closebrace", ")")
+	K2("semicolon", "semicolon", ";")
+	K2("quote", "quote", "'")
+	K2("backslash", "backslash", "\\\\")
+	K2("less", "less", "<")
+	K2("comma", "comma", ",")
+	K2("period", "period", ".")
+	K2("slash", "slash", "/")
+	K2("colon", "colon", ":")
+	K2("pound", "pound", "£")
+	K2("doublequote", "doublequote", "\"")
+	K2("diesis", "diessi", "#")
 
-	KR3("lshift", "lshift", "left?shift", "shift?left")
-	KR3("rshift", "rshift", "right?shift", "shift?right")
-	KR4("lctrl", "lctrl", "lcontrol", "left?ctrl", "ctrl?left")
-	KR4("rctrl", "rctrl", "rcontrol", "right?ctrl", "ctrl?right")
-	KR3("lalt", "lalt", "left?alt", "alt?left")
-	KR3("ralt", "ralt", "right?alt", "alt?right")
-	KR2("ctrl", "ctrl", "control")
+	K3("lshift", "lshift", "left?shift", "shift?left")
+	K3("rshift", "rshift", "right?shift", "shift?right")
+	K4("lctrl", "lctrl", "lcontrol", "left?ctrl", "ctrl?left")
+	K4("rctrl", "rctrl", "rcontrol", "right?ctrl", "ctrl?right")
+	K3("lalt", "lalt", "left?alt", "alt?left")
+	K3("ralt", "ralt", "right?alt", "alt?right")
+	K2("ctrl", "ctrl", "control")
 	K("alt")
 	K("shift")
 
 	/* it's safe to have directions as last entries to prevent incorrect */
 	/* recognition of "ctrl left" or similar */
-	KR2("left", "left", "cursor*left")
-	KR2("right", "right", "cursor*right")
-	KR2("up", "up", "cursor*up")
-	KR2("down", "down", "cursor*down")
+	K2("left", "left", "cursor*left")
+	K2("right", "right", "cursor*right")
+	K2("up", "up", "cursor*up")
+	K2("down", "down", "cursor*down")
 
 	K("f1")
 	K("f2")
@@ -1111,6 +1092,135 @@ static struct glue_keyboard_name GLUE_KEYBOARD_STD[] = {
 };
 #endif
 
+/**
+ * Other port name definitions.
+ */
+static struct glue_port_name GLUE_OTHER_STD[] = {
+
+	O2("stats", "stats", "statistics")
+	O("start")
+	O("select")
+	O("collect")
+	O("enter")
+	O("stop")
+	O1("stop_1", "stop?1")
+	O1("stop_2", "stop?2")
+	O1("stop_3", "stop?3")
+	O2("pay", "pay", "payout")
+	O("bet")
+	O1("cancel", "cancel*")
+	O1("call", "call*")
+	O("confirm")
+	O("take")
+	O("hp")
+	O("play")
+	O("small")
+	O("big")
+	O("double")
+	O("analyzer")
+	O("advance")
+	O("yes")
+	O("no")
+	O("chi")
+	O("pon")
+	O("kan")
+	O("reach")
+	O("ron")
+	O("red")
+	O("black")
+	O2("grid", "grid", "toggle?grid")
+	O1("p1_pad_1", "p1?pad?1")
+	O1("p1_pad_2", "p1?pad?2")
+	O1("p1_pad_3", "p1?pad?3")
+	O1("p1_pad_4", "p1?pad?4")
+	O1("p1_pad_5", "p1?pad?5")
+	O1("p1_pad_6", "p1?pad?6")
+	O1("p1_pad_7", "p1?pad?7")
+	O1("p1_pad_8", "p1?pad?8")
+	O1("p1_pad_9", "p1?pad?9")
+	O1("p2_pad_1", "p2?pad?1")
+	O1("p2_pad_2", "p2?pad?2")
+	O1("p2_pad_3", "p2?pad?3")
+	O1("p2_pad_4", "p2?pad?4")
+	O1("p2_pad_5", "p2?pad?5")
+	O1("p2_pad_6", "p2?pad?6")
+	O1("p2_pad_7", "p2?pad?7")
+	O1("p2_pad_8", "p2?pad?8")
+	O1("p2_pad_9", "p2?pad?9")
+
+	O("reset")
+	O1("memory_reset", "memory?reset")
+	O1("hopper_reset", "hopper?reset")
+	O1("high_score_reset", "high?score?reset")
+	O1("auto_up", "auto?up")
+	O1("auto_down", "auto?down")
+
+	O("up")
+	O2("down", "down", "key?down")
+	O("left")
+	O("right")
+
+	O1("top_center", "top?center")
+	O1("bottom_center", "bottom?center")
+	O1("top_left", "top?left")
+	O1("bottom_left", "bottom?left")
+	O1("top_right", "top?right")
+	O1("bottom_right", "bottom?right")
+
+	O1("hook_right", "hook?right")
+	O1("hook_left", "hook?left")
+
+	O1("left_trig", "l?trig")
+	O1("right_trig", "r?trig")
+
+	O2("next", "next", "next?game")
+	O2("previous", "previous", "previous?game")
+	O3("test", "test", "test switch", "test 1")
+	O2("operator", "operator", "operator?menu")
+	O("suicide")
+	O2("center", "center", "move?to?center")
+
+	O2("0", "0", "option?0")
+	O2("1", "1", "option?1")
+	O2("2", "2", "option?2")
+	O2("3", "3", "option?3")
+	O2("4", "4", "option?4")
+	O2("5", "5", "option?5")
+	O2("6", "6", "option?6")
+	O2("7", "7", "option?7")
+	O2("8", "8", "option?8")
+	O2("9", "9", "option?9")
+
+	O("q")
+	O("w")
+	O("e")
+	O("r")
+	O("t")
+	O("y")
+	O("u")
+	O("i")
+	O("o")
+	O("p")
+	O3("a", "a", "game?a", "skill?a")
+	O("s")
+	O("d")
+	O("f")
+	O("g")
+	O("h")
+	O("j")
+	O("k")
+	O("l")
+	O("z")
+	O("x")
+	O3("c", "c", "game?c", "skill?c")
+	O("v")
+	O3("b", "b", "game?b", "skill?b")
+	O("n")
+	O("m"){
+		0
+	}
+};
+
 /**
  * Input ports.
  * The port number are in a special uniqe format which allow to have different
@@ -1572,6 +1682,42 @@ static unsigned glue_keyboard_find(const char* const_name)
 }
 #endif
 
+static unsigned glue_other_find(const char* const_name)
+{
+	int i;
+	char name_buffer[128];
+	char* name;
+	char* s;
+	unsigned name_len;
+	unsigned j, k;
+
+	if (!const_name) {
+		log_std(("WARNING:glue: other port without a name\n"));
+		return 0;
+	}
+
+	/* duplicate */
+	sncpy(name_buffer, sizeof(name_buffer), const_name);
+	name = name_buffer;
+
+	/* comparison is in lower case */
+	osd_strlwr(name);
+
+	/* search for exact match */
+	for (j = 0; GLUE_OTHER_STD[j].name; ++j) {
+		for (k = 0; GLUE_OTHER_STD[j].glob[k]; ++k) {
+			if (sglob(name_buffer, GLUE_OTHER_STD[j].glob[k])) {
+				log_std(("glue: map other '%s' to control '%s' (exact)\n", name, GLUE_OTHER_STD[j].name));
+				return MAME_PORT_OTHER(j);
+			}
+		}
+	}
+
+	log_std(("WARNING:glue: other port '%s' not recognized\n", name));
+
+	return 0;
+}
+
 /**
  * Begin index of sequences for a MAME port type.
  */
@@ -1713,12 +1859,17 @@ unsigned glue_port_convert(unsigned type, unsigned player, unsigned seqtype, con
 	unsigned index;
 
 #ifdef MESS
-	/* keyboard ports have a special recongnition */
+	/* keyboard ports have a special recognition */
 	if (type == IPT_KEYBOARD) {
 		return glue_keyboard_find(name);
 	}
 #endif
 
+	/* other ports have a special recognition */
+	if (type == IPT_OTHER) {
+		return glue_other_find(name);
+	}
+
 	if (port_type_is_analog(type)) {
 		switch (seqtype) {
 		case SEQ_TYPE_STANDARD:  /* used for the mame_analog port */
@@ -3098,6 +3249,16 @@ adv_error mame_init(struct advance_context* context)
 	}
 #endif
 
+	/* add the keyboard names */
+	for (i = 0; GLUE_OTHER_STD[i].name; ++i) {
+		if (j + 1 < GLUE_PORT_MAX) {
+			GLUE_PORT[j].name = GLUE_OTHER_STD[i].name;
+			GLUE_PORT[j].desc = GLUE_OTHER_STD[i].desc;
+			GLUE_PORT[j].port = MAME_PORT_OTHER(i);
+			++j;
+		}
+	}
+
 	if (j + 1 >= GLUE_PORT_MAX) {
 		printf("Internal error, increase GLUE_PORT_MAX!\n");
 		abort();
@@ -3224,6 +3385,16 @@ adv_error mame_config_load(adv_conf* cfg_context, struct mame_option* option)
 			log_std((" "));
 		}
 	}
+	for (i = 0; GLUE_OTHER_STD[i].name; ++i) {
+		j += strlen(GLUE_OTHER_STD[i].name) + 2;
+		log_std(("%s,", GLUE_OTHER_STD[i].name));
+		if (j > 54) {
+			j = 0;
+			log_std(("\n\t\t"));
+		} else {
+			log_std((" "));
+		}
+	}
 	log_std(("\n"));
 #endif
 #endif
