@@ -101,7 +101,6 @@ struct mame_option {
 	char bios_buffer[MAME_MAXBIOS];
 
 #ifdef MESS
-	char crc_dir_buffer[MAME_MAXPATH];
 	struct mame_image* image_map[MAME_MAXIMAGE];
 	unsigned image_mac;
 	unsigned ram;
@@ -234,6 +233,9 @@ struct mame_digital_map_entry {
 #define MAME_PORT_KEYBOARD(keyboard) \
 	MAME_PORT_INDEX(IPT_KEYBOARD, 0, keyboard)
 
+#define MAME_PORT_OTHER(other) \
+	MAME_PORT_INDEX(IPT_OTHER, 0, other)
+
 #define MAME_PORT_TYPE_GET(port) \
 	(((port) & MAME_PORT_TYPE_MASK) >> MAME_PORT_TYPE_SHIFT)
 
