@@ -128,9 +128,9 @@ static int video_pipeline_menu(struct advance_video_context* context, struct adv
 	snprintf(buffer, sizeof(buffer), "Video Pipeline (%d)", context->state.blit_pipeline_index);
 	advance_ui_menu_title_insert(&menu, buffer);
 
-	for (i = 1, stage = video_pipeline_begin(&context->state.blit_pipeline[context->state.blit_pipeline_index]); stage != video_pipeline_end(&context->state.blit_pipeline[context->state.blit_pipeline_index]); ++stage, ++i) {
-		if (stage == video_pipeline_pivot(&context->state.blit_pipeline[context->state.blit_pipeline_index])) {
-			snprintf(buffer, sizeof(buffer), "(%d) %s", i, pipe_name(video_pipeline_vert(&context->state.blit_pipeline[context->state.blit_pipeline_index])->type));
+	for (i = 1, stage = video_pipeline_begin(&context->state.blit_pipeline); stage != video_pipeline_end(&context->state.blit_pipeline); ++stage, ++i) {
+		if (stage == video_pipeline_pivot(&context->state.blit_pipeline)) {
+			snprintf(buffer, sizeof(buffer), "(%d) %s", i, pipe_name(video_pipeline_vert(&context->state.blit_pipeline)->type));
 			advance_ui_menu_text_insert(&menu, buffer);
 			++i;
 		}
@@ -140,41 +140,21 @@ static int video_pipeline_menu(struct advance_video_context* context, struct adv
 			snprintf(buffer, sizeof(buffer), "(%d) %s, p %d", i, pipe_name(stage->type), stage->sbpp);
 		advance_ui_menu_text_insert(&menu, buffer);
 	}
-	if (stage == video_pipeline_pivot(&context->state.blit_pipeline[context->state.blit_pipeline_index])) {
-		snprintf(buffer, sizeof(buffer), "(%d) %s", i, pipe_name(video_pipeline_vert(&context->state.blit_pipeline[context->state.blit_pipeline_index])->type));
+	if (stage == video_pipeline_pivot(&context->state.blit_pipeline)) {
+		snprintf(buffer, sizeof(buffer), "(%d) %s", i, pipe_name(video_pipeline_vert(&context->state.blit_pipeline)->type));
 		advance_ui_menu_text_insert(&menu, buffer);
 		++i;
 	}
 
 	advance_ui_menu_title_insert(&menu, "Pipeline Blit Time");
 
-	if (context->state.pipeline_measure_flag) {
-		advance_ui_menu_text_insert(&menu, "Time measure not completed");
-	} else {
-		double timing = adv_measure_median(0.00001, 0.5, context->state.update_timing_map, PIPELINE_MEASURE_MAX);
-		snprintf(buffer, sizeof(buffer), "Last render %.2f (ms)", timing * 1000);
-		advance_ui_menu_text_insert(&menu, buffer);
+	double timing = adv_measure_median(0.00001, 0.5, context->state.update_timing_map, PIPELINE_MEASURE_MAX);
+	snprintf(buffer, sizeof(buffer), "Last render %.2f (ms)", timing * 1000);
+	advance_ui_menu_text_insert(&menu, buffer);
 
-		timing = adv_measure_median(0.00001, 0.5, context->state.pipeline_timing_map, PIPELINE_MEASURE_MAX);
-		snprintf(buffer, sizeof(buffer), "Last write %.2f (ms)", timing * 1000);
-		advance_ui_menu_text_insert(&menu, buffer);
-
-		for (i = 0; i < PIPELINE_BLIT_MAX; ++i) {
-			const char* desc;
-			const char* select;
-			if (context->state.blit_pipeline_index == i)
-				select = "-> ";
-			else
-				select = "";
-			switch (i) {
-			case 0: desc = "Buffer"; break;
-			case 1: desc = "Direct"; break;
-			default: desc = "Unknown"; break;
-			}
-			snprintf(buffer, sizeof(buffer), "%s%s write %.2f (ms)", select, desc, context->state.pipeline_measure_result[i] * 1000);
-			advance_ui_menu_text_insert(&menu, buffer);
-		}
-	}
+	timing = adv_measure_median(0.00001, 0.5, context->state.pipeline_timing_map, PIPELINE_MEASURE_MAX);
+	snprintf(buffer, sizeof(buffer), "Last write %.2f (ms)", timing * 1000);
+	advance_ui_menu_text_insert(&menu, buffer);
 
 	exit_index = advance_ui_menu_text_insert(&menu, "Return to Main Menu");
 
