@@ -30,6 +30,612 @@
 
 /* the first match is used */
 
+{ "matchit2", 7 }, /* 4.1 */
+{ "tfrceacjpb", 12 }, /* 4.1 */
+{ "bublbob2p", 6 }, /* 4.1 */
+{ "backfirt", 8 }, /* 4.1 */
+{ "eeekk", 9 }, /* 4.1 */
+{ "igmo", 8 }, /* 4.1 */
+{ "mastfury", 13 }, /* 4.1 */
+{ "py2k2", 3 }, /* 4.1 */
+{ "jumpkun", 4 }, /* 4.1 */
+{ "dicegame", 2 }, /* 4.1 */
+{ "olds", 4 }, /* 4.1 */
+{ "puzlstar", 3 }, /* 4.1 */
+{ "killbld", 5 }, /* 4.1 */
+{ "kov2", 15 }, /* 4.1 */
+{ "kov", 20 }, /* 4.1 */
+{ "photoy2k", 3 }, /* 4.1 */
+{ "drgw2c", 2 }, /* 4.1 */
+{ "tmntmwb", 3 }, /* 4.1 */
+{ "legendsb", 13 }, /* 4.1 */
+{ "rushbets", 6 }, /* 4.1 */
+{ "venom", 7 }, /* 4.1 */
+{ "wldgunsb", 2 }, /* 4.1 */
+{ "endless", 6 }, /* 4.1 */
+{ "denseib", 2 }, /* 4.1 */
+{ "iron", 12 }, /* 4.1 */
+{ "sblast2b", 6 }, /* 4.1 */
+{ "ffight2b", 4 }, /* 4.1 */
+{ "kinstb", 8 }, /* 4.1 */
+{ "ninjakun", 26 }, /* 4.1 */
+{ "metamrph", 14 }, /* 4.1 */
+{ "gaiapols", 22 }, /* 4.1 */
+{ "mmaulers", 22 }, /* 4.1 */
+{ "saiyugb2", 10 }, /* 4.1 */
+{ "mirax", 12 }, /* 4.1 */
+{ "bcruzm12", 22 }, /* 4.1 */
+{ "3kokushi", 2 }, /* 4.1 */
+{ "4enraya", 4 }, /* 4.1 */
+{ "4in1", 2 }, /* 4.1 */
+{ "4psimasy", 6 }, /* 4.1 */
+{ "8ball", 5 }, /* 4.1 */
+{ "abunai", 5 }, /* 4.1 */
+{ "ad2083", 4 }, /* 4.1 */
+{ "airwolf", 2 }, /* 4.1 */
+{ "alienar", 2 }, /* 4.1 */
+{ "aligatun", 11 }, /* 4.1 */
+{ "ambush", 2 }, /* 4.1 */
+{ "animaljr", 2 }, /* 4.1 */
+{ "ar_airh", 28 }, /* 4.1 */
+{ "ar_bowl", 30 }, /* 4.1 */
+{ "ar_dart", 32 }, /* 4.1 */
+{ "ar_fast", 35 }, /* 4.1 */
+{ "ar_ldrb", 29 }, /* 4.1 */
+{ "ar_ninj", 31 }, /* 4.1 */
+{ "ar_rdwr", 29 }, /* 4.1 */
+{ "ar_sdwr", 31 }, /* 4.1 */
+{ "ar_socc", 31 }, /* 4.1 */
+{ "ar_spot", 32 }, /* 4.1 */
+{ "ar_sprg", 30 }, /* 4.1 */
+{ "ar_xeon", 30 }, /* 4.1 */
+{ "archrivl", 2 }, /* 4.1 */
+{ "area51mx", 6 }, /* 4.1 */
+{ "aso", 4 }, /* 4.1 */
+{ "asurabus", 3 }, /* 4.1 */
+{ "atehate", 2 }, /* 4.1 */
+{ "atomicp", 2 }, /* 4.1 */
+{ "bakutotu", 6 }, /* 4.1 */
+{ "bananadr", 3 }, /* 4.1 */
+{ "barek3mb", 4 }, /* 4.1 */
+{ "battlcry", 2 }, /* 4.1 */
+{ "berlwall", 2 }, /* 4.1 */
+{ "bermudat", 5 }, /* 4.1 */
+{ "berzerk", 10 }, /* 4.1 */
+{ "bigbucks", 13 }, /* 4.1 */
+{ "bigevglf", 12 }, /* 4.1 */
+{ "bigfight", 5 }, /* 4.1 */
+{ "bigkarnk", 17 }, /* 4.1 */
+{ "bijokkog", 7 }, /* 4.1 */
+{ "bijokkoy", 8 }, /* 4.1 */
+{ "birdtry", 6 }, /* 4.1 */
+{ "bishi", 4 }, /* 4.1 */
+{ "bkrtmaq", 10 }, /* 4.1 */
+{ "bloodwar", 2 }, /* 4.1 */
+{ "bloxeed", 5 }, /* 4.1 */
+{ "bmcbowl", 7 }, /* 4.1 */
+{ "bombbee", 6 }, /* 4.1 */
+{ "botanic", 6 }, /* 4.1 */
+{ "brapboys", 13 }, /* 4.1 */
+{ "buccanrs", 2 }, /* 4.1 */
+{ "buggychl", 2 }, /* 4.1 */
+{ "bullfgtr", 3 }, /* 4.1 */
+{ "bullsdrt", 2 }, /* 4.1 */
+{ "calorie", 3 }, /* 4.1 */
+{ "cannball", 2 }, /* 4.1 */
+{ "cgangpzl", 7 }, /* 4.1 */
+{ "champbb2", 7 }, /* 4.1 */
+{ "chinagat", 6 }, /* 4.1 */
+{ "chinatwn", 15 }, /* 4.1 */
+{ "chinhero", 7 }, /* 4.1 */
+{ "chinmoku", 5 }, /* 4.1 */
+{ "chopper", 5 }, /* 4.1 */
+{ "chqflag", 8 }, /* 4.1 */
+{ "citylove", 4 }, /* 4.1 */
+{ "cltchitr", 7 }, /* 4.1 */
+{ "club90s", 6 }, /* 4.1 */
+{ "cmehyou", 3 }, /* 4.1 */
+{ "cnbe2018", 5 }, /* 4.1 */
+{ "commandw", 8 }, /* 4.1 */
+{ "contcirc", 2 }, /* 4.1 */
+{ "cookbib", 5 }, /* 4.1 */
+{ "coolmini", 4 }, /* 4.1 */
+{ "coolpool", 23 }, /* 4.1 */
+{ "cosmos", 5 }, /* 4.1 */
+{ "crgolf", 7 }, /* 4.1 */
+{ "crgolfhi", 7 }, /* 4.1 */
+{ "crimec", 3 }, /* 4.1 */
+{ "crkdown", 16 }, /* 4.1 */
+{ "crysking", 4 }, /* 4.1 */
+{ "crystal2", 3 }, /* 4.1 */
+{ "crystalg", 4 }, /* 4.1 */
+{ "csclub", 10 }, /* 4.1 */
+{ "cstlevna", 18 }, /* 4.1 */
+{ "cutefght", 4 }, /* 4.1 */
+{ "cutieq", 9 }, /* 4.1 */
+{ "cworld2j", 7 }, /* 4.1 */
+{ "cyclwarr", 5 }, /* 4.1 */
+{ "daiskiss", 11 }, /* 4.1 */
+{ "daitorid", 8 }, /* 4.1 */
+{ "daiyogen", 2 }, /* 4.1 */
+{ "darkplnt", 2 }, /* 4.1 */
+{ "darktowr", 2 }, /* 4.1 */
+{ "darkwar", 13 }, /* 4.1 */
+{ "dazzler", 2 }, /* 4.1 */
+{ "dblewing", 2 }, /* 4.1 */
+{ "dcclub", 12 }, /* 4.1 */
+{ "dcheese", 3 }, /* 4.1 */
+{ "ddungeon", 3 }, /* 4.1 */
+{ "deerhunt", 8 }, /* 4.1 */
+{ "diggerc", 3 }, /* 4.1 */
+{ "dockman", 3 }, /* 4.1 */
+{ "dreamwld", 5 }, /* 4.1 */
+{ "drgnbstr", 2 }, /* 4.1 */
+{ "drgnunit", 5 }, /* 4.1 */
+{ "drgpunch", 3 }, /* 4.1 */
+{ "drivfrcp", 4 }, /* 4.1 */
+{ "drtomy", 3 }, /* 4.1 */
+{ "dynagear", 4 }, /* 4.1 */
+{ "dynobop", 6 }, /* 4.1 */
+{ "ebases", 3 }, /* 4.1 */
+{ "egghunt", 9 }, /* 4.1 */
+{ "espial", 3 }, /* 4.1 */
+{ "eto", 2 }, /* 4.1 */
+{ "explbrkr", 4 }, /* 4.1 */
+{ "exvania", 14 }, /* 4.1 */
+{ "f1dream", 2 }, /* 4.1 */
+{ "f1gpstr2", 4 }, /* 4.1 */
+{ "fantzn2x", 6 }, /* 4.1 */
+{ "fax", 57 }, /* 4.1 */
+{ "fghthist", 2 }, /* 4.1 */
+{ "fieldday", 2 }, /* 4.1 */
+{ "finalizr", 3 }, /* 4.1 */
+{ "firebatl", 7 }, /* 4.1 */
+{ "fireshrk", 3 }, /* 4.1 */
+{ "fixeighb", 6 }, /* 4.1 */
+{ "flashgal", 2 }, /* 4.1 */
+{ "foodf", 7 }, /* 4.1 */
+{ "fredmem", 7 }, /* 4.1 */
+{ "freekick", 2 }, /* 4.1 */
+{ "frenzy", 10 }, /* 4.1 */
+{ "fromanc4", 6 }, /* 4.1 */
+{ "fromance", 4 }, /* 4.1 */
+{ "fromancr", 6 }, /* 4.1 */
+{ "funkyfig", 4 }, /* 4.1 */
+{ "funnymou", 3 }, /* 4.1 */
+{ "gaialast", 2 }, /* 4.1 */
+{ "gakusai", 2 }, /* 4.1 */
+{ "gakusai2", 3 }, /* 4.1 */
+{ "gal10ren", 4 }, /* 4.1 */
+{ "galivan", 2 }, /* 4.1 */
+{ "galkaika", 5 }, /* 4.1 */
+{ "galkoku", 4 }, /* 4.1 */
+{ "gauntlet", 2 }, /* 4.1 */
+{ "gekiretu", 5 }, /* 4.1 */
+{ "genix", 2 }, /* 4.1 */
+{ "genpeitd", 6 }, /* 4.1 */
+{ "ghlpanic", 4 }, /* 4.1 */
+{ "ghox", 3 }, /* 4.1 */
+{ "gionbana", 7 }, /* 4.1 */
+{ "gladiatr", 4 }, /* 4.1 */
+{ "glasskr", 10 }, /* 4.1 */
+{ "gldncrwn", 4 }, /* 4.1 */
+{ "goldbug", 3 }, /* 4.1 */
+{ "goldstar", 2 }, /* 4.1 */
+{ "gomoku", 7 }, /* 4.1 */
+{ "gpgolf", 6 }, /* 4.1 */
+{ "grobda", 6 }, /* 4.1 */
+{ "gtmr2", 4 }, /* 4.1 */
+{ "guzzler", 2 }, /* 4.1 */
+{ "hachamf", 2 }, /* 4.1 */
+{ "hanaawas", 9 }, /* 4.1 */
+{ "hanakanz", 6 }, /* 4.1 */
+{ "hanamai", 3 }, /* 4.1 */
+{ "hanamomo", 3 }, /* 4.1 */
+{ "hanaoji", 4 }, /* 4.1 */
+{ "hardhat", 36 }, /* 4.1 */
+{ "hardhea2", 14 }, /* 4.1 */
+{ "hatena", 4 }, /* 4.1 */
+{ "hcrash", 7 }, /* 4.1 */
+{ "heartatk", 3 }, /* 4.1 */
+{ "hgkairak", 3 }, /* 4.1 */
+{ "hkagerou", 6 }, /* 4.1 */
+{ "hnoridur", 4 }, /* 4.1 */
+{ "holeland", 2 }, /* 4.1 */
+{ "horshoes", 11 }, /* 4.1 */
+{ "hotdebut", 5 }, /* 4.1 */
+{ "hotgmck", 2 }, /* 4.1 */
+{ "hotgmck3", 2 }, /* 4.1 */
+{ "hotsmash", 10 }, /* 4.1 */
+{ "housemn2", 5 }, /* 4.1 */
+{ "housemnq", 5 }, /* 4.1 */
+{ "hunchbkg", 5 }, /* 4.1 */
+{ "hustler", 3 }, /* 4.1 */
+{ "hvysmsh", 10 }, /* 4.1 */
+{ "hyhoo", 3 }, /* 4.1 */
+{ "hyhoo2", 4 }, /* 4.1 */
+{ "hypreac2", 12 }, /* 4.1 */
+{ "hypreact", 8 }, /* 4.1 */
+{ "idhimitu", 4 }, /* 4.1 */
+{ "iemoto", 4 }, /* 4.1 */
+{ "imago", 2 }, /* 4.1 */
+{ "imekura", 6 }, /* 4.1 */
+{ "insectx", 2 }, /* 4.1 */
+{ "inufuku", 12 }, /* 4.1 */
+{ "jackrabt", 4 }, /* 4.1 */
+{ "janbari", 4 }, /* 4.1 */
+{ "jogakuen", 3 }, /* 4.1 */
+{ "kabukiz", 2 }, /* 4.1 */
+{ "kageki", 2 }, /* 4.1 */
+{ "kaguya", 5 }, /* 4.1 */
+{ "kaguya2", 5 }, /* 4.1 */
+{ "kaitei", 4 }, /* 4.1 */
+{ "kaos", 2 }, /* 4.1 */
+{ "kbash2", 7 }, /* 4.1 */
+{ "keithlcy", 8 }, /* 4.1 */
+{ "kikikai", 2 }, /* 4.1 */
+{ "kikstart", 2 }, /* 4.1 */
+{ "killcom", 3 }, /* 4.1 */
+{ "kingball", 5 }, /* 4.1 */
+{ "knckhead", 13 }, /* 4.1 */
+{ "kodure", 4 }, /* 4.1 */
+{ "koinomp", 5 }, /* 4.1 */
+{ "korinai", 4 }, /* 4.1 */
+{ "kouyakyu", 3 }, /* 4.1 */
+{ "kungfut", 17 }, /* 4.1 */
+{ "ladyfrog", 2 }, /* 4.1 */
+{ "ladykill", 2 }, /* 4.1 */
+{ "lasthope", 15 }, /* 4.1 */
+{ "le2", 8 }, /* 4.1 */
+{ "legend", 2 }, /* 4.1 */
+{ "legion", 3 }, /* 4.1 */
+{ "lemnangl", 2 }, /* 4.1 */
+{ "lethalen", 2 }, /* 4.1 */
+{ "lnc", 3 }, /* 4.1 */
+{ "logger", 4 }, /* 4.1 */
+{ "macross", 2 }, /* 4.1 */
+{ "madmotor", 4 }, /* 4.1 */
+{ "magic10", 16 }, /* 4.1 */
+{ "mahmajn", 11 }, /* 4.1 */
+{ "mahmajn2", 10 }, /* 4.1 */
+{ "maiko", 4 }, /* 4.1 */
+{ "maniacsq", 7 }, /* 4.1 */
+{ "manybloc", 2 }, /* 4.1 */
+{ "marukin", 4 }, /* 4.1 */
+{ "maya", 3 }, /* 4.1 */
+{ "mayjisn2", 3 }, /* 4.1 */
+{ "mchampdx", 9 }, /* 4.1 */
+{ "mcnpshnt", 4 }, /* 4.1 */
+{ "mcontest", 4 }, /* 4.1 */
+{ "mechatt", 3 }, /* 4.1 */
+{ "megadon", 2 }, /* 4.1 */
+{ "megatack", 2 }, /* 4.1 */
+{ "megazone", 6 }, /* 4.1 */
+{ "meijinsn", 3 }, /* 4.1 */
+{ "metlsavr", 5 }, /* 4.1 */
+{ "mf_flip", 3 }, /* 4.1 */
+{ "mfunclub", 2 }, /* 4.1 */
+{ "mgakuen2", 2 }, /* 4.1 */
+{ "mgion", 6 }, /* 4.1 */
+{ "mgmen89", 4 }, /* 4.1 */
+{ "mhgaiden", 3 }, /* 4.1 */
+{ "mhhonban", 6 }, /* 4.1 */
+{ "midres", 8 }, /* 4.1 */
+{ "mjangels", 4 }, /* 4.1 */
+{ "mjcamera", 3 }, /* 4.1 */
+{ "mjcamerb", 3 }, /* 4.1 */
+{ "mjchuuka", 7 }, /* 4.1 */
+{ "mjclinic", 3 }, /* 4.1 */
+{ "mjdchuka", 8 }, /* 4.1 */
+{ "mjderngr", 4 }, /* 4.1 */
+{ "mjdialq2", 3 }, /* 4.1 */
+{ "mjdiplob", 2 }, /* 4.1 */
+{ "mjegolf", 5 }, /* 4.1 */
+{ "mjelctrn", 4 }, /* 4.1 */
+{ "mjfocus", 5 }, /* 4.1 */
+{ "mjgottsu", 2 }, /* 4.1 */
+{ "mjgottub", 3 }, /* 4.1 */
+{ "mjhokite", 3 }, /* 4.1 */
+{ "mjkinjas", 2 }, /* 4.1 */
+{ "mjkoiura", 3 }, /* 4.1 */
+{ "mjlaman", 4 }, /* 4.1 */
+{ "mjlstory", 5 }, /* 4.1 */
+{ "mjmyster", 5 }, /* 4.1 */
+{ "mjnanpas", 4 }, /* 4.1 */
+{ "mjnatsu", 2 }, /* 4.1 */
+{ "mjnquest", 2 }, /* 4.1 */
+{ "mjreach1", 2 }, /* 4.1 */
+{ "mjsikaku", 3 }, /* 4.1 */
+{ "mjsister", 2 }, /* 4.1 */
+{ "mjuraden", 3 }, /* 4.1 */
+{ "mkeibaou", 4 }, /* 4.1 */
+{ "mladyhtr", 3 }, /* 4.1 */
+{ "mmaiko", 4 }, /* 4.1 */
+{ "mmehyou", 2 }, /* 4.1 */
+{ "mmpanic", 3 }, /* 4.1 */
+{ "mnight", 36 }, /* 4.1 */
+{ "mofflott", 11 }, /* 4.1 */
+{ "mogura", 8 }, /* 4.1 */
+{ "monymony", 4 }, /* 4.1 */
+{ "moonal2", 3 }, /* 4.1 */
+{ "moremore", 2 }, /* 4.1 */
+{ "mp_bio", 6 }, /* 4.1 */
+{ "mp_col3", 7 }, /* 4.1 */
+{ "mrgoemon", 7 }, /* 4.1 */
+{ "mrokumei", 3 }, /* 4.1 */
+{ "mscoutm", 4 }, /* 4.1 */
+{ "msgogo", 2 }, /* 4.1 */
+{ "msjiken", 3 }, /* 4.1 */
+{ "mstworld", 3 }, /* 4.1 */
+{ "musobana", 7 }, /* 4.1 */
+{ "nametune", 11 }, /* 4.1 */
+{ "nastar", 2 }, /* 4.1 */
+{ "natodef", 3 }, /* 4.1 */
+{ "ncv2", 5 }, /* 4.1 */
+{ "neckneck", 3 }, /* 4.1 */
+{ "neobattl", 6 }, /* 4.1 */
+{ "neruton", 4 }, /* 4.1 */
+{ "nettoqc", 7 }, /* 4.1 */
+{ "netwars", 2 }, /* 4.1 */
+{ "ngpgal", 3 }, /* 4.1 */
+{ "ninclown", 4 }, /* 4.1 */
+{ "nmsengen", 3 }, /* 4.1 */
+{ "ntopstar", 3 }, /* 4.1 */
+{ "nyny", 4 }, /* 4.1 */
+{ "ohmygod", 2 }, /* 4.1 */
+{ "ojankoc", 3 }, /* 4.1 */
+{ "ojankohs", 4 }, /* 4.1 */
+{ "ojousan", 4 }, /* 4.1 */
+{ "omotesnd", 5 }, /* 4.1 */
+{ "orangec", 4 }, /* 4.1 */
+{ "otatidai", 4 }, /* 4.1 */
+{ "otonano", 3 }, /* 4.1 */
+{ "otwalls", 10 }, /* 4.1 */
+{ "pacappsp", 10 }, /* 4.1 */
+{ "pachiten", 3 }, /* 4.1 */
+{ "packbang", 2 }, /* 4.1 */
+{ "paddlema", 6 }, /* 4.1 */
+{ "pairs", 3 }, /* 4.1 */
+{ "pairsnb", 7 }, /* 4.1 */
+{ "pangpang", 2 }, /* 4.1 */
+{ "paradice", 4 }, /* 4.1 */
+{ "paradise", 3 }, /* 4.1 */
+{ "paradlx", 4 }, /* 4.1 */
+{ "pass", 2 }, /* 4.1 */
+{ "pastelg", 5 }, /* 4.1 */
+{ "patimono", 5 }, /* 4.1 */
+{ "pignewt", 4 }, /* 4.1 */
+{ "pigskin", 3 }, /* 4.1 */
+{ "pkgnsh", 4 }, /* 4.1 */
+{ "pkgnshdx", 4 }, /* 4.1 */
+{ "plgirls", 3 }, /* 4.1 */
+{ "plotting", 3 }, /* 4.1 */
+{ "poitto", 4 }, /* 4.1 */
+{ "pokio", 3 }, /* 4.1 */
+{ "pokrdice", 7 }, /* 4.1 */
+{ "ponpoko", 8 }, /* 4.1 */
+{ "popper", 2 }, /* 4.1 */
+{ "ppmast93", 8 }, /* 4.1 */
+{ "profpac", 18 }, /* 4.1 */
+{ "progress", 3 }, /* 4.1 */
+{ "psailor1", 4 }, /* 4.1 */
+{ "psailor2", 3 }, /* 4.1 */
+{ "pstadium", 4 }, /* 4.1 */
+{ "pyramid", 4 }, /* 4.1 */
+{ "qad", 2 }, /* 4.1 */
+{ "qcrayon", 5 }, /* 4.1 */
+{ "qcrayon2", 14 }, /* 4.1 */
+{ "qdrmfgp", 17 }, /* 4.1 */
+{ "qgakumon", 9 }, /* 4.1 */
+{ "qgh", 13 }, /* 4.1 */
+{ "qix", 2 }, /* 4.1 */
+{ "qjinsei", 5 }, /* 4.1 */
+{ "qmhayaku", 3 }, /* 4.1 */
+{ "qndream", 2 }, /* 4.1 */
+{ "qntoond", 2 }, /* 4.1 */
+{ "qrouka", 4 }, /* 4.1 */
+{ "qsangoku", 2 }, /* 4.1 */
+{ "qsww", 15 }, /* 4.1 */
+{ "qtheater", 10 }, /* 4.1 */
+{ "qtono1", 2 }, /* 4.1 */
+{ "qtono2", 7 }, /* 4.1 */
+{ "qtorimon", 12 }, /* 4.1 */
+{ "quasar", 2 }, /* 4.1 */
+{ "quintoon", 3 }, /* 4.1 */
+{ "quiz18k", 2 }, /* 4.1 */
+{ "quiz365", 7 }, /* 4.1 */
+{ "quizf1", 8 }, /* 4.1 */
+{ "quizhq", 6 }, /* 4.1 */
+{ "quizhuhu", 11 }, /* 4.1 */
+{ "quizmeku", 15 }, /* 4.1 */
+{ "quizmoon", 9 }, /* 4.1 */
+{ "quizpani", 2 }, /* 4.1 */
+{ "quiztou", 10 }, /* 4.1 */
+{ "quiztvqq", 3 }, /* 4.1 */
+{ "qzchikyu", 4 }, /* 4.1 */
+{ "qzkklogy", 5 }, /* 4.1 */
+{ "qzquest", 5 }, /* 4.1 */
+{ "qzshowby", 2 }, /* 4.1 */
+{ "racingb", 4 }, /* 4.1 */
+{ "rackemup", 4 }, /* 4.1 */
+{ "radarzon", 3 }, /* 4.1 */
+{ "raiders", 6 }, /* 4.1 */
+{ "rambo3", 3 }, /* 4.1 */
+{ "raphero", 2 }, /* 4.1 */
+{ "rchase", 6 }, /* 4.1 */
+{ "redbaron", 2 }, /* 4.1 */
+{ "redrobin", 2 }, /* 4.1 */
+{ "redufo", 4 }, /* 4.1 */
+{ "renaiclb", 5 }, /* 4.1 */
+{ "renegade", 2 }, /* 4.1 */
+{ "renju", 3 }, /* 4.1 */
+{ "rescraid", 11 }, /* 4.1 */
+{ "ridingf", 8 }, /* 4.1 */
+{ "ringrage", 3 }, /* 4.1 */
+{ "riot", 16 }, /* 4.1 */
+{ "rjammer", 2 }, /* 4.1 */
+{ "rockn", 2 }, /* 4.1 */
+{ "rockn2", 2 }, /* 4.1 */
+{ "rocknms", 6 }, /* 4.1 */
+{ "rockrage", 4 }, /* 4.1 */
+{ "rocktrv2", 18 }, /* 4.1 */
+{ "rohga", 3 }, /* 4.1 */
+{ "rolcrush", 11 }, /* 4.1 */
+{ "rongrong", 3 }, /* 4.1 */
+{ "roundup5", 5 }, /* 4.1 */
+{ "royalmah", 8 }, /* 4.1 */
+{ "rranger", 3 }, /* 4.1 */
+{ "ryorioh", 2 }, /* 4.1 */
+{ "ryouran", 11 }, /* 4.1 */
+{ "ryukyu", 5 }, /* 4.1 */
+{ "sailorws", 5 }, /* 4.1 */
+{ "salmndr2", 17 }, /* 4.1 */
+{ "sauro", 5 }, /* 4.1 */
+{ "sbdk", 3 }, /* 4.1 */
+{ "sbm", 6 }, /* 4.1 */
+{ "scandal", 3 }, /* 4.1 */
+{ "sci", 3 }, /* 4.1 */
+{ "scion", 5 }, /* 4.1 */
+{ "scorpnmc", 2 }, /* 4.1 */
+{ "scotrsht", 2 }, /* 4.1 */
+{ "scudhamm", 3 }, /* 4.1 */
+{ "sderby", 25 }, /* 4.1 */
+{ "sdgndmps", 4 }, /* 4.1 */
+{ "secolove", 6 }, /* 4.1 */
+{ "seiha", 4 }, /* 4.1 */
+{ "semibase", 2 }, /* 4.1 */
+{ "shogwarr", 7 }, /* 4.1 */
+{ "shrike", 11 }, /* 4.1 */
+{ "sjryuko", 2 }, /* 4.1 */
+{ "skyskipr", 2 }, /* 4.1 */
+{ "slapfigh", 18 }, /* 4.1 */
+{ "slapshot", 7 }, /* 4.1 */
+{ "slikshot", 6 }, /* 4.1 */
+{ "slipstrm", 6 }, /* 4.1 */
+{ "slither", 3 }, /* 4.1 */
+{ "slotsnl", 3 }, /* 4.1 */
+{ "sltblgpo", 3 }, /* 4.1 */
+{ "sltblgtk", 4 }, /* 4.1 */
+{ "snapper", 8 }, /* 4.1 */
+{ "solfigtr", 2 }, /* 4.1 */
+{ "sonic2mb", 4 }, /* 4.1 */
+{ "sonofphx", 2 }, /* 4.1 */
+{ "sos", 4 }, /* 4.1 */
+{ "spacefrt", 5 }, /* 4.1 */
+{ "spacegun", 3 }, /* 4.1 */
+{ "spdball", 10 }, /* 4.1 */
+{ "spectar", 3 }, /* 4.1 */
+{ "spiders", 4 }, /* 4.1 */
+{ "spy", 4 }, /* 4.1 */
+{ "srdmissn", 2 }, /* 4.1 */
+{ "srmp2", 2 }, /* 4.1 */
+{ "srmp3", 2 }, /* 4.1 */
+{ "srmp4", 3 }, /* 4.1 */
+{ "srmp7", 3 }, /* 4.1 */
+{ "sslam", 2 }, /* 4.1 */
+{ "ssoldier", 9 }, /* 4.1 */
+{ "ssonicbr", 4 }, /* 4.1 */
+{ "sspirits", 14 }, /* 4.1 */
+{ "sstrike", 7 }, /* 4.1 */
+{ "stargrds", 11 }, /* 4.1 */
+{ "steeltal", 5 }, /* 4.1 */
+{ "stoffy", 3 }, /* 4.1 */
+{ "stompin", 4 }, /* 4.1 */
+{ "strahl", 13 }, /* 4.1 */
+{ "stratgyx", 3 }, /* 4.1 */
+{ "stratof", 14 }, /* 4.1 */
+{ "suikoenb", 20 }, /* 4.1 */
+{ "superman", 2 }, /* 4.1 */
+{ "suprridr", 5 }, /* 4.1 */
+{ "suprtrio", 3 }, /* 4.1 */
+{ "suratk", 7 }, /* 4.1 */
+{ "survarts", 3 }, /* 4.1 */
+{ "svf", 2 }, /* 4.1 */
+{ "swa", 16 }, /* 4.1 */
+{ "sxyreac2", 4 }, /* 4.1 */
+{ "taiwanmb", 5 }, /* 4.1 */
+{ "talbot", 4 }, /* 4.1 */
+{ "tankbatt", 3 }, /* 4.1 */
+{ "tankfrce", 3 }, /* 4.1 */
+{ "taotaido", 7 }, /* 4.1 */
+{ "taxidrvr", 3 }, /* 4.1 */
+{ "tekipaki", 20 }, /* 4.1 */
+{ "teljan", 11 }, /* 4.1 */
+{ "telmahjn", 4 }, /* 4.1 */
+{ "tenkomor", 3 }, /* 4.1 */
+{ "tetrisse", 7 }, /* 4.1 */
+{ "tgm2", 22 }, /* 4.1 */
+{ "thedeep", 8 }, /* 4.1 */
+{ "thief", 4 }, /* 4.1 */
+{ "thoop", 6 }, /* 4.1 */
+{ "timelimt", 2 }, /* 4.1 */
+{ "tmekprot", 7 }, /* 4.1 */
+{ "tmnt2", 5 }, /* 4.1 */
+{ "tokyogal", 2 }, /* 4.1 */
+{ "topgun", 17 }, /* 4.1 */
+{ "topshoot", 10 }, /* 4.1 */
+{ "toride2g", 3 }, /* 4.1 */
+{ "totc", 14 }, /* 4.1 */
+{ "touchgok", 6 }, /* 4.1 */
+{ "trckydoc", 6 }, /* 4.1 */
+{ "triplew1", 3 }, /* 4.1 */
+{ "triplew2", 4 }, /* 4.1 */
+{ "tripool", 3 }, /* 4.1 */
+{ "triviabb", 11 }, /* 4.1 */
+{ "triviaes", 11 }, /* 4.1 */
+{ "triviag1", 11 }, /* 4.1 */
+{ "triviag2", 11 }, /* 4.1 */
+{ "triviasp", 13 }, /* 4.1 */
+{ "triviayp", 11 }, /* 4.1 */
+{ "trophyh", 11 }, /* 4.1 */
+{ "tstrike", 2 }, /* 4.1 */
+{ "turkhunt", 5 }, /* 4.1 */
+{ "tutankhm", 2 }, /* 4.1 */
+{ "twins", 6 }, /* 4.1 */
+{ "twinsqua", 2 }, /* 4.1 */
+{ "twotigrc", 2 }, /* 4.1 */
+{ "tylz", 2 }, /* 4.1 */
+{ "uchuuai", 5 }, /* 4.1 */
+{ "ultennis", 8 }, /* 4.1 */
+{ "ultramhm", 4 }, /* 4.1 */
+{ "umanclub", 4 }, /* 4.1 */
+{ "uniwars", 3 }, /* 4.1 */
+{ "upscope", 7 }, /* 4.1 */
+{ "usg182", 10 }, /* 4.1 */
+{ "usg185", 12 }, /* 4.1 */
+{ "usg252", 12 }, /* 4.1 */
+{ "usg83", 2 }, /* 4.1 */
+{ "vanilla", 5 }, /* 4.1 */
+{ "vastar", 4 }, /* 4.1 */
+{ "vblokbrk", 2 }, /* 4.1 */
+{ "vbowlj", 4 }, /* 4.1 */
+{ "venture", 30 }, /* 4.1 */
+{ "victory", 58 }, /* 4.1 */
+{ "viofight", 4 }, /* 4.1 */
+{ "vroulet", 7 }, /* 4.1 */
+{ "wargods", 27 }, /* 4.1 */
+{ "warpwarp", 4 }, /* 4.1 */
+{ "wbml", 2 }, /* 4.1 */
+{ "wcatcher", 3 }, /* 4.1 */
+{ "wcbowldx", 4 }, /* 4.1 */
+{ "wfortune", 2 }, /* 4.1 */
+{ "whodunit", 31 }, /* 4.1 */
+{ "wildfang", 7 }, /* 4.1 */
+{ "wildplt", 2 }, /* 4.1 */
+{ "wingforc", 3 }, /* 4.1 */
+{ "wingwar", 8 }, /* 4.1 */
+{ "wizzquiz", 11 }, /* 4.1 */
+{ "wschamp", 5 }, /* 4.1 */
+{ "wwestern", 6 }, /* 4.1 */
+{ "xorworld", 10 }, /* 4.1 */
+{ "xtheball", 2 }, /* 4.1 */
+{ "xyonix", 3 }, /* 4.1 */
+{ "yarunara", 4 }, /* 4.1 */
+{ "yesnoj", 5 }, /* 4.1 */
+{ "yosimoto", 4 }, /* 4.1 */
+{ "yujan", 12 }, /* 4.1 */
+{ "yuka", 12 }, /* 4.1 */
+{ "yuyugogo", 6 }, /* 4.1 */
 { "tkmmpzdm", 22 }, /* 4.0 */
 { "3in1semi", 4 }, /* 4.0 */
 { "woodpek", 2 }, /* 4.0 */
@@ -145,7 +751,6 @@
 { "pow", 16 }, /* 4.0 */
 { "othellos", 20 }, /* 4.0 */
 { "orlegend", 4 }, /* 4.0 */
-{ "olds103t", 5 }, /* 4.0 */
 { "opwolf", 3 }, /* 4.0 */
 { "othunder", 2 }, /* 4.0 */
 { "opaopan", 2 }, /* 4.0 */
@@ -158,7 +763,6 @@
 { "mvp", 5 }, /* 4.0 */
 { "docastle", 2 }, /* 4.0 */
 { "mtrap", 35 }, /* 4.0 */
-{ "mmaulers", 22 }, /* 4.0 */
 { "gdfs", 9 }, /* 4.0 */
 { "missile", 9 }, /* 4.0 */
 { "mpangj", 9 }, /* 4.0 */
@@ -173,8 +777,6 @@
 { "crshrace", 8 }, /* 4.0 */
 { "lastmisn", 10 }, /* 4.0 */
 { "kram", 6 }, /* 4.0 */
-{ "kov2", 8 }, /* 4.0 */
-{ "kov", 19 }, /* 4.0 */
 { "horekid", 3 }, /* 4.0 */
 { "jungler", 6 }, /* 4.0 */
 { "vshoot", 5 }, /* 4.0 */
@@ -271,14 +873,12 @@
 { "glfgreat", 4 }, /* 4.0 */
 { "hvoltage", 4 }, /* 4.0 */
 { "splndrbt", 4 }, /* 4.0 */
-{ "killbldt", 20 }, /* 4.0 */
 { "lordgun", 10 }, /* 4.0 */
 { "roadriot", 10 }, /* 4.0 */
 { "winspike", 13 }, /* 4.0 */
 { "cbombers", 13 }, /* 4.0 */
 { "hsf2", 15 }, /* 4.0 */
 { "leds2011", 9 }, /* 4.0 */
-{ "mirax", 18 }, /* 4.0 */
 { "cosmogng", 4 }, /* 3.11 */
 { "batsugun", 11 }, /* 3.11 */
 { "fghtatck", 9 }, /* 3.11 */
@@ -578,7 +1178,6 @@
 { "amidar", 4 }, /* 0.81 */
 { "anteater", 3 }, /* 0.81 */
 { "aquajack", 2 }, /* 0.81 */
-{ "arabfgt", 12 }, /* 0.81 */
 { "arabianm", 3 }, /* 0.81 */
 { "arbalest", 4 }, /* 0.81 */
 { "area51", 10 }, /* 0.81 */
