@@ -260,6 +260,9 @@ static adv_error sdl_init(int device_id, adv_output output, unsigned overlay_siz
 
 	log_std(("video:sdl: sdl_init(id:%d,output:%d,overlay_size:%d)\n", device_id, (unsigned)output, overlay_size));
 
+	memset(&sdl_state, 0, sizeof(sdl_state));
+	initialized_now = 0;
+
 	if (sizeof(sdl_video_mode) > MODE_DRIVER_MODE_SIZE_MAX) {
 		error_set("Invalid structure size.\n");
 		goto err;
@@ -267,7 +270,7 @@ static adv_error sdl_init(int device_id, adv_output output, unsigned overlay_siz
 
 	if (!os_internal_sdl_get()) {
 		error_set("Unsupported without the SDL library.\n");
-		return -1;
+		goto err;
 	}
 
 #if defined(USE_VIDEO_SVGALIB)
@@ -284,7 +287,12 @@ static adv_error sdl_init(int device_id, adv_output output, unsigned overlay_siz
 	}
 #endif
 
-	memset(&sdl_state, 0, sizeof(sdl_state));
+#ifdef USE_VC
+	if (!target_wm()) {
+		error_set("With VideoCore you can use SDL only from a Window Manager.\n");
+		goto err;
+	}
+#endif
 
 	sdl_state.cursor = cursor;
 
@@ -294,8 +302,6 @@ static adv_error sdl_init(int device_id, adv_output output, unsigned overlay_siz
 	if (!i->name)
 		goto err;
 
-	initialized_now = 0;
-
 	if (SDL_WasInit(SDL_INIT_VIDEO) == 0) {
 		log_std(("video:sdl: call SDL_InitSubSystem(SDL_INIT_VIDEO)\n"));
 
@@ -628,12 +634,14 @@ static adv_error sdl_init(int device_id, adv_output output, unsigned overlay_siz
 #ifdef USE_VC /* only for Raspberry */
 	if (has_window_manager) {
 		/*
-		 * In X the opengl/opengles/opengles2 renderers are very very slow.
+		 * In X the opengl/opengles/opengles2 renderers are slower than the software one.
 		 *
-		 * To write a texture of 640x480 (ARGB8888 format) takes more than 100 ms,
-		 * when isntead the software renderer takes 3 ms.
+		 * This applies to both the "-output overlay" and "-output window" modes.
 		 *
-		 * Tested with SDL2 2.0.5 and Raspbian updated 6/1/2017.
+		 * Verified with SDL2 2.0.5 and Raspbian "jessie" 6/1/2017 on Raspberry 3B+.
+		 * Verified with SDL2 2.0.9 and Raspbian "buster" 26/9/2019 on Raspberry 4.
+		 *
+		 * You can override with the environment variable SDL_RENDER_DRIVER=...
 		 */
 		SDL_SetHintWithPriority(SDL_HINT_RENDER_DRIVER, "software", SDL_HINT_DEFAULT);
 	}
@@ -1236,18 +1244,28 @@ adv_error sdl_scroll(unsigned offset, adv_bool waitvsync)
 	if (offset != 0)
 		return -1;
 
+#if SDL_MAJOR_VERSION != 1
 	/* normalize to 0 1 */
 	waitvsync = waitvsync != 0;
 
-#if SDL_MAJOR_VERSION != 1
-	/* reset the renderer if the thread or the vsync request change */
-	if (
-#ifdef USE_SMP
-		sdl_state.thread != pthread_self() ||
+/* SDL_RenderSetVSync is available only from 2.18 */
+#if SDL_MAJOR_VERSION > 2 || (SDL_MAJOR_VERSION == 2 && SDL_MAJOR_VERSION >= 18)
+	/* update the vsync configuration */
+	if (waitvsync != sdl_state.overlay_vsync) {
+		log_std(("video:sdl: change renderer vsync. New vsync=%d\n", waitvsync));
+		sdl_state.overlay_vsync = waitvsync;
+		SDL_RenderSetVSync(sdl_state.renderer, waitvsync);
+	}
 #endif
+
+	/* reset the renderer if the thread or vsync change */
+	if (
 		waitvsync != sdl_state.overlay_vsync
+#ifdef USE_SMP
+		|| sdl_state.thread != pthread_self()
+#endif
 	) {
-		log_std(("video:sdl: recompute renderer for thread/vsync change. New vsync=%d\n", waitvsync));
+		log_std(("video:sdl: recompute renderer for thread/vsync change\n"));
 		sdl_state.overlay_vsync = waitvsync;
 		sdl_overlay_set();
 	}
