@@ -590,18 +590,18 @@ INPUT_PORTS_START( a2600 )
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1) PORT_CATEGORY(2) PORT_PLAYER(1)
 
 	PORT_START /* [8] SWCHB */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Reset Game") PORT_CODE(KEYCODE_2)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START) PORT_NAME("Select Game")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START) PORT_NAME("Reset") PORT_CODE(KEYCODE_2)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SELECT) PORT_NAME("Select")
 	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_DIPNAME( 0x08, 0x08, "TV Type" ) PORT_CODE(KEYCODE_C) PORT_TOGGLE
+	PORT_DIPNAME( 0x08, 0x08, "TV Type" ) PORT_TOGGLE // PORT_CODE(KEYCODE_C) PORT_TOGGLE
 	PORT_DIPSETTING(    0x08, "Color" )
 	PORT_DIPSETTING(    0x00, "B&W" )
 	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_DIPNAME( 0x40, 0x00, "Left Diff. Switch" ) PORT_CODE(KEYCODE_3) PORT_TOGGLE
+	PORT_DIPNAME( 0x40, 0x00, "Left Diff. Switch" ) PORT_TOGGLE // PORT_CODE(KEYCODE_3) PORT_TOGGLE
 	PORT_DIPSETTING(    0x40, "A" )
 	PORT_DIPSETTING(    0x00, "B" )
-	PORT_DIPNAME( 0x80, 0x00, "Right Diff. Switch" ) PORT_CODE(KEYCODE_4) PORT_TOGGLE
+	PORT_DIPNAME( 0x80, 0x00, "Right Diff. Switch" ) PORT_TOGGLE // PORT_CODE(KEYCODE_4) PORT_TOGGLE
 	PORT_DIPSETTING(    0x80, "A" )
 	PORT_DIPSETTING(    0x00, "B" )
 
