@@ -175,6 +175,11 @@ enum
 	CPU_RSP,
 	CPU_ALPHA8201,
 	CPU_ALPHA8301,
+	CPU_TMP90840,
+	CPU_TMP90841,
+	CPU_TMP91640,
+	CPU_TMP91641,
+	CPU_MB86233,
 #ifdef MESS
 	CPU_APEXC,
 	CPU_CDP1802,
