@@ -358,261 +358,11 @@ static READ8_HANDLER( pix2_r )
 }
 
 
-/****************************************************************************
-                        fake MCU (undoukai and field day)
-****************************************************************************/
-
-static int from_mcu;
-static int mcu_cmd;
-
-static UINT8 mcu_in[2][16],mcu_out[2][16];
-
-static const UINT8 mcu_data0[0x80] =
-{
-	0x0a,0x08,0x0f,0x07,0x06,0x05,0x04,0x00,
-	0x0a,0x0b,0x15,0x02,0x03,0x15,0x0a,0x08,
-	0x0f,0x07,0x06,0x05,0x04,0x0c,0x01,0x0c,
-	0x01,0x15,0x0b,0x0a,0x00,0x0d,0x0e,0x15,
-	0x0a,0x08,0x0f,0x07,0x06,0x05,0x04,0x0b,
-	0x09,0x0c,0x01,0x0c,0x01,0x15,0x0a,0x08,
-	0x0f,0x07,0x06,0x05,0x04,0x0c,0x0c,0x01,
-	0x0c,0x0c,0xff,0xe1,0x23,0xc5,0xc9,0x15,
-
-	0x3e,0x4a,0xcd,0x2b,0x00,0x4e,0x79,0xf6,
-	0xa0,0xe6,0xa2,0xcb,0xcf,0xf5,0x0e,0x62,
-	0xcd,0x35,0x00,0xcb,0xc9,0x79,0xe6,0x02,
-	0x5f,0xe1,0x4b,0x69,0x3e,0x00,0x2e,0x38,
-	0xb5,0x6f,0x06,0x23,0x11,0xfe,0xdf,0x1a,
-	0x27,0x77,0xe6,0x01,0x5f,0x16,0x00,0xcb,
-	0xfe,0x19,0x05,0x78,0x20,0xee,0xc1,0xe1,
-	0x23,0xc5,0xc9,0xee,0x37,0x28,0xc0,0xc5
-};
-
-static const UINT8 mcu_data1[0x80] =
-{
-	0x00,0x78,0xef,0x66,0xdc,0x50,0xc2,0x33,
-	0xa1,0x0c,0x74,0xd9,0x3a,0x96,0xef,0x42,
-	0x90,0xd9,0x1c,0x58,0x8f,0xbe,0xe6,0x07,
-	0x20,0x31,0x39,0x39,0x2f,0x1c,0x00,0xda,
-	0xa9,0x6d,0x27,0xd6,0x79,0x11,0x9c,0x1b,
-	0x8e,0xf3,0x4c,0x97,0xd5,0x05,0x27,0x3a,
-	0x3f,0x35,0x1b,0xf3,0xbb,0x73,0x1c,0xb4,
-	0x3c,0xb3,0x1a,0x6f,0xb4,0xe7,0x09,0x19,
-	0x17,0x04,0xde,0xa6,0x5c,0xff,0x90,0x0e,
-	0x78,0xd0,0x15,0x47,0x65,0x70,0x68,0x4c,
-	0x1c,0xd9,0x82,0x18,0x99,0x07,0x60,0xa6,
-	0xd8,0xf6,0x00,0x30,0x08,0x31,0x02,0xb7,
-	0x81,0xfa,0x30,0x02,0x01,0x01,0x14,0x30,
-	0x07,0xd6,0x7e,0x30,0x1d,0x15,0x25,0xff,
-	0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
-	0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff
-};
-
-static const UINT8 mcu_data2[0x80] =
-{
-	0x00,0x04,0x08,0x00,0x11,0x16,0x1a,0x1f,
-	0x23,0x28,0x2c,0x30,0x35,0x39,0x3d,0x42,
-	0x46,0x4a,0x4f,0x53,0x57,0x5b,0x5f,0x64,
-	0x68,0x6c,0x70,0x74,0x78,0x7c,0x80,0x83,
-	0x87,0x8b,0x8f,0x92,0x96,0x9a,0x90,0xa1,
-	0xa4,0xa7,0xa8,0xae,0xb1,0xb5,0xb8,0xbb,
-	0xbe,0xc1,0xc4,0xc6,0xc9,0xcc,0xcf,0xd1,
-	0xd4,0xd6,0xd9,0xdb,0xdd,0xdf,0xe2,0xe4,
-	0xe6,0xe8,0xe9,0xeb,0xed,0xee,0xf0,0xf2,
-	0xf3,0xf4,0xf6,0xf7,0xf8,0xf9,0xfa,0xfb,
-	0xfc,0xfc,0xfd,0xfe,0xfe,0xff,0xff,0xff,
-	0xff,0xff,0x00,0x3d,0x26,0xbe,0xd6,0x6c,
-	0x30,0xa6,0xb7,0x81,0x01,0x04,0x14,0xb6,
-	0xa4,0x97,0x02,0xb7,0x81,0x1b,0x13,0x23,
-	0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
-	0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff
-};
-
-
-static WRITE8_HANDLER( undoukai_mcu_w )
-{
-	UINT8 *RAM = memory_region(REGION_CPU1);
-	UINT16 ram_adr = RAM[0xa1b5]*0x100 + RAM[0xa1b4];
-
-	int d;
-	int i;
-
-//  logerror("mcu_w %02x\n",data);
-
-
-	if (mcu_cmd != -1)
-	{
-		mcu_in[(mcu_cmd & 0x10)>>4][mcu_cmd & 0x0f] = data;
-		mcu_cmd = -1;
-	}
-	else
-	{
-		switch (data)
-		{
-			case 0xc0:
-			case 0xc1:
-			case 0xc2:
-			case 0xc3:
-			case 0xc4:
-			case 0xc5:
-			case 0xc6:
-			case 0xc7:
-				mcu_cmd = (data & 0x0f) | 0x10;
-				break;
-
-			case 0xb0:
-			case 0xb1:
-			case 0xb2:
-			case 0xb3:
-				mcu_cmd = data & 0x0f;
-				break;
-
-
-			case 0x30:
-			case 0x31:
-			case 0x32:
-			case 0x33:
-			case 0x34:
-			case 0x35:
-			case 0x36:
-			case 0x37:
-			case 0x38:
-			case 0x39:
-				from_mcu = mcu_out[0][data & 0x0f];
-				break;
-
-			case 0x40:
-			case 0x41:
-			case 0x42:
-				from_mcu = mcu_out[1][data & 0x0f];
-				break;
-
-
-
-			case 0x01:
-				mcu_out[0][0] = (mcu_in[0][0] ^ (mcu_in[0][0] >> 4)) & 0x0f;
-				break;
-
-			case 0x02:
-				if (mcu_in[0][3] != 0x00)
-				{
-					mcu_out[0][1] = 0x0c;
-					mcu_out[0][2] = 0x00;
-				}
-				else
-				{
-					mcu_out[0][2] = 0xa2;
-					switch (mcu_in[0][0] & 0x03)
-					{
-						case 0: mcu_out[0][1] = 0x55; break;
-						case 1: mcu_out[0][1] = 0x3d; break;
-						case 2: mcu_out[0][1] = 0x45; break;
-						case 3: mcu_out[0][1] = 0x4d; break;
-					}
-				}
-				break;
-
-			case 0x03:
-				mcu_out[0][1] = (((mcu_in[0][0] * 8) & 0x38) -1) & 0xff ;
-
-				if (mcu_in[0][1] | mcu_in[0][2])
-					d = 0x40;
-				else
-					d = 0x00;
-
-				for (i=0;i<8;i++)
-					mcu_out[0][i+2] = mcu_data0[((mcu_out[0][1] + i) & 0x3f) + d];
-				break;
-
-			case 0x04:
-				mcu_out[0][0] = ((mcu_in[0][0] & 0x0f) << 4) + (mcu_in[0][1] & 0x0f);
-				mcu_out[0][1] = ((mcu_in[0][2] & 0x0f) << 4) + (mcu_in[0][3] & 0x0f);
-				break;
-
-			case 0x05:
-//              mcu_out[0][0] = 255*cos(PI*mcu_in[0][0]/180);
-//              mcu_out[0][1] = 255*sin(PI*mcu_in[0][0]/180);
-
-				d = mcu_in[0][0] & 0x7f;
-				mcu_out[0][0] = mcu_data1[d];
-				mcu_out[0][1] = mcu_data2[d];
-				break;
-
-			case 0x06:
-				if (mcu_in[0][0] != 0x00)
-					mcu_out[0][0] = 0xfa;
-				else
-					switch (mcu_in[0][1])
-					{
-						case 0x00: mcu_out[0][0] = 0x02; break;
-						case 0x01: mcu_out[0][0] = 0x01; break;
-						case 0x02: mcu_out[0][0] = 0x01; break;
-						case 0x03: mcu_out[0][0] = 0x04; break;
-						case 0x04: mcu_out[0][0] = 0x01; break;
-						case 0x05: mcu_out[0][0] = 0x14; break;
-						case 0x06: mcu_out[0][0] = 0x14; break;
-						case 0x07: mcu_out[0][0] = 0xb6; break;
-						default:
-						//  ui_popup("cmd06: %02x %02x",mcu_in[0][0],mcu_in[0][1]);
-							logerror("cmd06: %02x %02x\n",mcu_in[0][0],mcu_in[0][1]);
-					}
-				break;
-
-			case 0x07:
-				switch (mcu_in[0][0] & 7)
-				{
-					case 0: mcu_out[0][0] = 0x1d; break;
-					case 1: mcu_out[0][0] = 0x1b; break;
-					case 2: mcu_out[0][0] = 0x15; break;
-					case 3: mcu_out[0][0] = 0x13; break;
-					case 4: mcu_out[0][0] = 0x25; break;
-					case 5: mcu_out[0][0] = 0x23; break;
-					case 6: mcu_out[0][0] = 0xff; break;
-					case 7: mcu_out[0][0] = 0xff; break;
-				}
-				break;
-
-			case 0x0e:
-				mcu_out[1][0] = RAM[ram_adr];
-				mcu_out[1][1] = RAM[ram_adr+1];
-				mcu_out[1][2] = RAM[ram_adr+2] & 0x0f;
-				break;
-
-
-			default:
-				from_mcu = 0x5d;
-
-//              ui_popup("unknown cmd%02x: %02x %02x %02x %02x",data,mcu_in[0][0],mcu_in[0][1],mcu_in[0][2],mcu_in[0][3]);
-//              logerror("unknown cmd%02x: %02x %02x %02x %02x\n",data,mcu_in[0][0],mcu_in[0][1],mcu_in[0][2],mcu_in[0][3]);
-		}
-	}
-}
-
-static READ8_HANDLER( undoukai_mcu_r )
-{
-
-//  logerror("mcu_r %02x\n",from_mcu);
-
-	return from_mcu;
-}
-
-static READ8_HANDLER( undoukai_mcu_status_r )
-{
-	int res = 3;
-
-	return res;
-}
-
-/***************************************************************************/
-
 static DRIVER_INIT( undoukai )
 {
 	UINT8 *ROM = memory_region(REGION_CPU1);
 	memory_configure_bank(1, 0, 2, &ROM[0x10000], 0x2000);
 
-	from_mcu = 0xff;
-	mcu_cmd = -1;
-
 	fortyl_pix_color[0] = 0x000;
 	fortyl_pix_color[1] = 0x1e3;
 	fortyl_pix_color[2] = 0x16c;
@@ -739,8 +489,8 @@ static ADDRESS_MAP_START( undoukai_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc000, 0xffff) AM_READ(fortyl_pixram_r)
 
 
-	AM_RANGE(0xa800, 0xa800) AM_READ(undoukai_mcu_r)
-	AM_RANGE(0xa801, 0xa801) AM_READ(undoukai_mcu_status_r)
+	AM_RANGE(0xa800, 0xa800) AM_READ(fortyl_mcu_r)
+	AM_RANGE(0xa801, 0xa801) AM_READ(fortyl_mcu_status_r)
 
 	//AM_RANGE(0xa802, 0xa802) AM_READ(pix1_r) // this one is here just for debugging
 	AM_RANGE(0xa803, 0xa803) AM_READ(pix2_r) // and this one _is_ used.
@@ -762,7 +512,7 @@ static ADDRESS_MAP_START( undoukai_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x8000, 0x9fff) AM_WRITE(MWA8_ROM)
 	AM_RANGE(0xa000, 0xa7ff) AM_WRITE(MWA8_RAM)	/* M5517P on main board */
 
-	AM_RANGE(0xa800, 0xa800) AM_WRITE(undoukai_mcu_w)
+	AM_RANGE(0xa800, 0xa800) AM_WRITE(fortyl_mcu_w)
 	AM_RANGE(0xa801, 0xa801) AM_WRITE(pix1_w)		//pixel layer related
 	AM_RANGE(0xa802, 0xa802) AM_WRITE(bank_select_w)
 	AM_RANGE(0xa803, 0xa803) AM_WRITE(pix2_w)		//pixel layer related
@@ -1233,11 +983,12 @@ static MACHINE_DRIVER_START( undoukai )
 	MDRV_CPU_PROGRAM_MAP(readmem_sound,writemem_sound)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,2)	/* source/number of IRQs is unknown */
 
-//  MDRV_CPU_ADD(M68705,18432000/6)
-//  MDRV_CPU_PROGRAM_MAP(mcu_readmem,mcu_writemem)
+        MDRV_CPU_ADD(M68705,18432000/6)
+        MDRV_CPU_PROGRAM_MAP(mcu_readmem,mcu_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_INTERLEAVE(100)	/* high interleave to ensure proper synchronization of CPUs */
 	MDRV_MACHINE_RESET(ta7630)	/* init machine */
 
 	/* video hardware */
@@ -1327,7 +1078,7 @@ ROM_START( fieldday )
 	ROM_LOAD( "a17_29.bin", 0xa000, 0x2000, CRC(3c540007) SHA1(549e7ff260214c538913ff548dcb088987845911) )
 
 	ROM_REGION( 0x0800, REGION_CPU3, 0 )	/* 2k for the microcontroller */
-	ROM_LOAD( "a17_14.bin", 0x0000, 0x0800, NO_DUMP )
+        ROM_LOAD( "a17_14.bin", 0x0000, 0x0800, CRC(a686894d) SHA1(0578747a1869db98ee1962822491103f3f082cba) )
 
 	ROM_REGION( 0x8000, REGION_GFX1, ROMREGION_DISPOSE )
 	ROM_LOAD( "a17_36.bin", 0x0000, 0x2000, CRC(e3dd51f7) SHA1(95a97ea925c5bc7bdc00887e6d17d817b36befc4) )
@@ -1365,8 +1116,8 @@ ROM_START( undoukai )
 	ROM_LOAD( "a17-13.39s", 0xa000, 0x2000, CRC(0a40930e) SHA1(8c4b9fa0aed67a3e269c2136ef81791fc8acd1da) )
 
 	ROM_REGION( 0x0800, REGION_CPU3, 0 )	/* 2k for the microcontroller */
-	ROM_LOAD( "a17-14.41c", 0x0000, 0x0800, NO_DUMP )
-
+        ROM_LOAD( "a17_14.bin", 0x0000, 0x0800, CRC(a686894d) SHA1(0578747a1869db98ee1962822491103f3f082cba) )
+ 
 	ROM_REGION( 0x8000, REGION_GFX1, ROMREGION_DISPOSE )
 	ROM_LOAD( "a17-04.18v", 0x0000, 0x4000, CRC(84dabee2) SHA1(698f12ee4201665988248853dafbf4b16dfc6517) )
 	ROM_LOAD( "a17-05.19v", 0x4000, 0x4000, CRC(10bf3451) SHA1(23ebb1409c90d225ff5a13ad23d4dff1acaf904a) )
