@@ -302,6 +302,12 @@ INPUT_PORTS_START( asteroid )
 	PORT_DIPSETTING (	0x80, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING (	0x40, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING (	0x00, DEF_STR( Free_Play ) )
+
+	PORT_START_TAG("COCKTAIL")
+	PORT_DIPNAME(1, 0, DEF_STR(Cabinet))
+	PORT_DIPSETTING(0, DEF_STR(Upright))
+	PORT_DIPSETTING(1, DEF_STR(Cocktail))
+
 INPUT_PORTS_END
 
 
@@ -475,6 +481,12 @@ INPUT_PORTS_START( astdelux )
 	PORT_DIPSETTING (	0xa0, "1 each 4" )
 	PORT_DIPSETTING (	0xc0, "1 each 2" )
 	PORT_DIPSETTING (	0xe0, DEF_STR( None ) )
+
+	PORT_START_TAG("COCKTAIL")
+	PORT_DIPNAME(1, 0, DEF_STR(Cabinet))
+	PORT_DIPSETTING(0, DEF_STR(Upright))
+	PORT_DIPSETTING(1, DEF_STR(Cocktail))
+    
 INPUT_PORTS_END
 
 
@@ -608,7 +620,7 @@ static MACHINE_DRIVER_START( asteroid )
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_VECTOR | VIDEO_RGB_DIRECT)
 	MDRV_SCREEN_SIZE(400,300)
-	MDRV_VISIBLE_AREA(0, 1040, 70, 950)
+	MDRV_VISIBLE_AREA(0, 1032, 0, 1050)
 	MDRV_PALETTE_LENGTH(32768)
 
 	MDRV_PALETTE_INIT(avg_white)
