@@ -517,10 +517,10 @@ static MACHINE_DRIVER_START( backfire )
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN )
 	MDRV_SCREEN_SIZE(80*8, 32*8)
-	MDRV_VISIBLE_AREA(0*8, 80*8-1, 1*8, 31*8-1)
+	MDRV_VISIBLE_AREA(0*8, 80*8/2-1, 1*8, 31*8-1) /* /2 makes it single monitor */
 	MDRV_GFXDECODE(gfxdecodeinfo_backfire)
 	MDRV_PALETTE_LENGTH(2048)
-	MDRV_ASPECT_RATIO(8,3)
+	MDRV_ASPECT_RATIO(8/2,3) /* /2 makes it single monitor */
 
 	MDRV_VIDEO_START(backfire)
 	MDRV_VIDEO_UPDATE(backfire)
