@@ -240,9 +240,6 @@ Notes:
 
 
 Notes:
-- the original bubble bobble board has a 68701 protection MCU, which hasn't been
-  read. Its behaviour is simulated and should be a good approximation but not
-  100% accurate.
 - The coin inputs are handled by a custom called PC030. It would be responsible of
   handling the coin counters.
 - There is a weird dip switch in Bubble Bobble (SWB #7). When it is on, the game
@@ -254,12 +251,14 @@ Notes:
   Frankly I don't know what this could be. The schematics don't show anything
   special there. A debug feature seems unlikely - why care about the score?
   Could it be provision for some kind of externally controlled redemption scheme?
-- "Attract Sound" in Tokio is a very relative term - it just plays a veryshort
+- "Attract Sound" in Tokio is a very relative term - it just plays a very short
   sound every four rounds of demo play.
 
 TODO:
-- bublbobl: the randomization of EXTEND letters is handled by the MCU. The simulation
-  is probably not accurate and the same letter might appear too many times.
+- the MCU is actually a 6801U4, which has additional features like internal timers
+  (similar to the HD63701). I've just mapped the I/O ports since that's the only
+    thing required for normal operation, but the program does use some of the
+    additional features in its special "test" mode.
 - emulate the CPU #1 <-> sound CPU communication status flags (which are not used)
 - why does emulating the sound CPU reset port (fa03) cause sound to stop working?
 - tokio: doesn't work due to missing MCU protection emulation.
@@ -272,6 +271,7 @@ TODO:
 #include "driver.h"
 #include "sound/2203intf.h"
 #include "sound/3812intf.h"
+#include "cpu/m6805/m6805.h"
 
 /* vidhrdw/bublbobl.c */
 extern UINT8 *bublbobl_objectram;
@@ -284,18 +284,33 @@ WRITE8_HANDLER( bublbobl_bankswitch_w );
 WRITE8_HANDLER( tokio_bankswitch_w );
 WRITE8_HANDLER( tokio_videoctrl_w );
 WRITE8_HANDLER( bublbobl_nmitrigger_w );
-READ8_HANDLER( tokio_mcu_r );
-READ8_HANDLER( tokiob_mcu_r );
 WRITE8_HANDLER( bublbobl_sound_command_w );
 WRITE8_HANDLER( bublbobl_sh_nmi_disable_w );
 WRITE8_HANDLER( bublbobl_sh_nmi_enable_w );
-INTERRUPT_GEN( bublbobl_interrupt );
 READ8_HANDLER( boblbobl_ic43_a_r );
 WRITE8_HANDLER( boblbobl_ic43_a_w );
 READ8_HANDLER( boblbobl_ic43_b_r );
 WRITE8_HANDLER( boblbobl_ic43_b_w );
+
+READ8_HANDLER( bublbobl_mcu_ddr1_r );
+WRITE8_HANDLER( bublbobl_mcu_ddr1_w );
+READ8_HANDLER( bublbobl_mcu_ddr2_r );
+WRITE8_HANDLER( bublbobl_mcu_ddr2_w );
+READ8_HANDLER( bublbobl_mcu_ddr3_r );
+WRITE8_HANDLER( bublbobl_mcu_ddr3_w );
+READ8_HANDLER( bublbobl_mcu_ddr4_r );
+WRITE8_HANDLER( bublbobl_mcu_ddr4_w );
+READ8_HANDLER( bublbobl_mcu_port1_r );
+WRITE8_HANDLER( bublbobl_mcu_port1_w );
+READ8_HANDLER( bublbobl_mcu_port2_r );
+WRITE8_HANDLER( bublbobl_mcu_port2_w );
+READ8_HANDLER( bublbobl_mcu_port3_r );
+WRITE8_HANDLER( bublbobl_mcu_port3_w );
+READ8_HANDLER( bublbobl_mcu_port4_r );
+WRITE8_HANDLER( bublbobl_mcu_port4_w );
+
 #if 0
-// left for reference. The 68705 was from a bootleg, the original MCU is a 68701
+// left for reference. The 68705 was from a bootleg, the original MCU is a 6801U4
 INTERRUPT_GEN( bublbobl_m68705_interrupt );
 READ8_HANDLER( bublbobl_68705_portA_r );
 WRITE8_HANDLER( bublbobl_68705_portA_w );
@@ -312,6 +327,126 @@ static WRITE8_HANDLER(soundcpu_reset_w)
 }
 #endif
 
+/* tokio mcu */
+READ8_HANDLER ( tokio_68705_portA_r );
+WRITE8_HANDLER( tokio_68705_portA_w );
+READ8_HANDLER ( tokio_68705_portB_r );
+WRITE8_HANDLER( tokio_68705_portB_w );
+READ8_HANDLER ( tokio_68705_portC_r );
+WRITE8_HANDLER( tokio_68705_portC_w );
+WRITE8_HANDLER( tokio_68705_ddrA_w );
+WRITE8_HANDLER( tokio_68705_ddrB_w );
+WRITE8_HANDLER( tokio_68705_ddrC_w );
+WRITE8_HANDLER( tokio_mcu_w );
+READ8_HANDLER ( tokio_mcu_r );
+READ8_HANDLER ( tokio_mcu_status_r );
+READ8_HANDLER ( tokio_fake_r ); /* faked mcu commands for bootleg */
+
+static unsigned char from_main,from_mcu;
+static int mcu_sent = 0,main_sent = 0;
+static unsigned char portA_in,portA_out,ddrA;
+static unsigned char portB_in,portB_out,ddrB;
+static unsigned char portC_in,portC_out,ddrC;
+
+READ8_HANDLER( tokio_68705_portA_r )
+{
+	return (portA_out & ddrA) | (portA_in & ~ddrA);
+}
+
+WRITE8_HANDLER( tokio_68705_portA_w )
+{
+	portA_out = data;
+}
+
+WRITE8_HANDLER( tokio_68705_ddrA_w )
+{
+	ddrA = data;
+}
+
+READ8_HANDLER( tokio_68705_portB_r )
+{
+	return (portB_out & ddrB) | (portB_in & ~ddrB);
+}
+
+WRITE8_HANDLER( tokio_68705_portB_w )
+{
+	if ((ddrB & 0x02) && (~data & 0x02) && (portB_out & 0x02))
+	{
+		portA_in = from_main;
+		if (main_sent) cpunum_set_input_line(3,0,CLEAR_LINE);
+		main_sent = 0;
+	}
+	if ((ddrB & 0x04) && (data & 0x04) && (~portB_out & 0x04))
+	{
+		from_mcu = portA_out;
+		mcu_sent = 1;
+	}
+
+	portB_out = data;
+}
+
+WRITE8_HANDLER( tokio_68705_ddrB_w )
+{
+	ddrB = data;
+}
+
+
+READ8_HANDLER( tokio_68705_portC_r )
+{
+	UINT8 ret = 0;
+
+	if (!main_sent)
+		ret |= 0x01;
+	if (mcu_sent)
+		ret |= 0x02;
+
+	ret ^= 0x3; /* inverted logic compared to tigerh */
+
+	return ret;
+
+}
+
+WRITE8_HANDLER( tokio_68705_portC_w )
+{
+	portC_out = data;
+}
+
+WRITE8_HANDLER( tokio_68705_ddrC_w )
+{
+	ddrC = data;
+}
+
+WRITE8_HANDLER( tokio_mcu_w )
+{
+	from_main = data;
+	main_sent = 1;
+	cpunum_set_input_line(3,0,ASSERT_LINE);
+}
+
+READ8_HANDLER( tokio_mcu_r )
+{
+	mcu_sent = 0;
+	return from_mcu;
+}
+
+READ8_HANDLER( tokio_mcu_status_r )
+{
+    int res = input_port_2_r(0);
+ 
+    res &= ~0x30; /* clear 3 bits in top nibble to make room for mcu status */
+ 
+    if (!main_sent)
+        res |= 0x10;
+    if (!mcu_sent)
+        res |= 0x20;
+ 
+    return res;
+}
+
+READ8_HANDLER( tokio_fake_r )
+{
+    return 0xbf; /* ad-hoc value set to pass initial testing */
+}
 
 static ADDRESS_MAP_START( master_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
@@ -345,8 +480,21 @@ static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xe000, 0xffff) AM_ROM	// space for diagnostic ROM?
 ADDRESS_MAP_END
 
+static ADDRESS_MAP_START( mcu_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x0000) AM_READWRITE(bublbobl_mcu_ddr1_r,  bublbobl_mcu_ddr1_w)
+	AM_RANGE(0x0001, 0x0001) AM_READWRITE(bublbobl_mcu_ddr2_r,  bublbobl_mcu_ddr2_w)
+	AM_RANGE(0x0002, 0x0002) AM_READWRITE(bublbobl_mcu_port1_r, bublbobl_mcu_port1_w)
+	AM_RANGE(0x0003, 0x0003) AM_READWRITE(bublbobl_mcu_port2_r, bublbobl_mcu_port2_w)
+	AM_RANGE(0x0004, 0x0004) AM_READWRITE(bublbobl_mcu_ddr3_r,  bublbobl_mcu_ddr3_w)
+	AM_RANGE(0x0005, 0x0005) AM_READWRITE(bublbobl_mcu_ddr4_r,  bublbobl_mcu_ddr4_w)
+	AM_RANGE(0x0006, 0x0006) AM_READWRITE(bublbobl_mcu_port3_r, bublbobl_mcu_port3_w)
+	AM_RANGE(0x0007, 0x0007) AM_READWRITE(bublbobl_mcu_port4_r, bublbobl_mcu_port4_w)
+	AM_RANGE(0x0040, 0x00ff) AM_RAM
+	AM_RANGE(0xf000, 0xffff) AM_ROM
+ADDRESS_MAP_END
+
 #if 0
-// left for reference. The 68705 was from a bootleg, the original MCU is a 68701
+// left for reference. The 68705 was from a bootleg, the original MCU is a 6801U4
 static ADDRESS_MAP_START( mcu_map, ADDRESS_SPACE_PROGRAM, 8 )
 	ADDRESS_MAP_FLAGS( AMEF_ABITS(11) )
 	AM_RANGE(0x000, 0x000) AM_READWRITE(bublbobl_68705_portA_r, bublbobl_68705_portA_w)
@@ -383,8 +531,28 @@ static ADDRESS_MAP_START( bootleg_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xff98, 0xff98) AM_WRITENOP // ???
 ADDRESS_MAP_END
 
-
 static ADDRESS_MAP_START( tokio_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK(1)
+	AM_RANGE(0xc000, 0xdcff) AM_RAM AM_BASE(&videoram) AM_SIZE(&videoram_size)
+	AM_RANGE(0xdd00, 0xdfff) AM_RAM AM_BASE(&bublbobl_objectram) AM_SIZE(&bublbobl_objectram_size)
+	AM_RANGE(0xe000, 0xf7ff) AM_RAM AM_SHARE(1)
+	AM_RANGE(0xf800, 0xf9ff) AM_RAM AM_WRITE(paletteram_RRRRGGGGBBBBxxxx_be_w) AM_BASE(&paletteram)
+	AM_RANGE(0xfa00, 0xfa00) AM_WRITE(watchdog_reset_w)
+	AM_RANGE(0xfa03, 0xfa03) AM_READ(input_port_0_r)
+	AM_RANGE(0xfa04, 0xfa04) AM_READ(input_port_1_r)
+	AM_RANGE(0xfa05, 0xfa05) AM_READ(tokio_mcu_status_r) /* M68705 commands */
+	AM_RANGE(0xfa06, 0xfa06) AM_READ(input_port_3_r)
+	AM_RANGE(0xfa07, 0xfa07) AM_READ(input_port_4_r)
+	AM_RANGE(0xfa80, 0xfa80) AM_WRITE(tokio_bankswitch_w)
+	AM_RANGE(0xfb00, 0xfb00) AM_WRITE(tokio_videoctrl_w)
+	AM_RANGE(0xfb80, 0xfb80) AM_WRITE(bublbobl_nmitrigger_w)
+	AM_RANGE(0xfc00, 0xfc00) AM_READNOP AM_WRITE(bublbobl_sound_command_w) // ???
+    AM_RANGE(0xfe00, 0xfe00) AM_READWRITE(tokio_mcu_r, tokio_mcu_w)
+ADDRESS_MAP_END
+
+/* bootleg uses fake mcu hookup */
+static ADDRESS_MAP_START( tokiob_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK(1)
 	AM_RANGE(0xc000, 0xdcff) AM_RAM AM_BASE(&videoram) AM_SIZE(&videoram_size)
@@ -401,7 +569,7 @@ static ADDRESS_MAP_START( tokio_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xfb00, 0xfb00) AM_WRITE(tokio_videoctrl_w)
 	AM_RANGE(0xfb80, 0xfb80) AM_WRITE(bublbobl_nmitrigger_w)
 	AM_RANGE(0xfc00, 0xfc00) AM_READNOP AM_WRITE(bublbobl_sound_command_w) // ???
-	AM_RANGE(0xfe00, 0xfe00) AM_READ(tokio_mcu_r) AM_WRITENOP // ???
+	AM_RANGE(0xfe00, 0xfe00) AM_READ(tokio_fake_r) AM_WRITENOP // ???
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( tokio_slave_map, ADDRESS_SPACE_PROGRAM, 8 )
@@ -421,14 +589,34 @@ static ADDRESS_MAP_START( tokio_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xe000, 0xffff) AM_ROM	// space for diagnostic ROM?
 ADDRESS_MAP_END
 
+static ADDRESS_MAP_START( tokio_m68705_readmem, ADDRESS_SPACE_PROGRAM, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(11) )
+	AM_RANGE(0x0000, 0x0000) AM_READ(tokio_68705_portA_r)
+	AM_RANGE(0x0001, 0x0001) AM_READ(tokio_68705_portB_r)
+	AM_RANGE(0x0002, 0x0002) AM_READ(tokio_68705_portC_r)
+	AM_RANGE(0x0010, 0x007f) AM_READ(MRA8_RAM)
+	AM_RANGE(0x0080, 0x07ff) AM_READ(MRA8_ROM)
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( tokio_m68705_writemem, ADDRESS_SPACE_PROGRAM, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(11) )
+	AM_RANGE(0x0000, 0x0000) AM_WRITE(tokio_68705_portA_w)
+	AM_RANGE(0x0001, 0x0001) AM_WRITE(tokio_68705_portB_w)
+	AM_RANGE(0x0002, 0x0002) AM_WRITE(tokio_68705_portC_w)
+	AM_RANGE(0x0004, 0x0004) AM_WRITE(tokio_68705_ddrA_w)
+	AM_RANGE(0x0005, 0x0005) AM_WRITE(tokio_68705_ddrB_w)
+	AM_RANGE(0x0006, 0x0006) AM_WRITE(tokio_68705_ddrC_w)
+	AM_RANGE(0x0010, 0x007f) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x0080, 0x07ff) AM_WRITE(MWA8_ROM)
+ADDRESS_MAP_END
 
 
 INPUT_PORTS_START( bublbobl )
 	PORT_START_TAG("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_TILT )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
-	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_IMPULSE(1)
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN1 )
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_COIN2 )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_SPECIAL )	// output: coin lockout
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_SPECIAL )	// output: select 1-way or 2-way coin counter
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_SPECIAL )	// output: trigger IRQ on main CPU (jumper switchable to vblank)
@@ -637,10 +825,10 @@ INPUT_PORTS_START( tokio )
 	PORT_START_TAG("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_TILT )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
-	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_IMPULSE(1)
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_SPECIAL )	// data ready from MCU
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN1 )
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_COIN2 )
+    PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_SPECIAL ) /* M68705 commands */
+	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_SPECIAL ) /* M68705 commands */
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
@@ -665,7 +853,84 @@ INPUT_PORTS_START( tokio )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 INPUT_PORTS_END
 
+/* bootleg no mcu */
+INPUT_PORTS_START( tokiob )
+	PORT_START_TAG("DSW0")
+	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Cabinet ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( Cocktail ) )
+	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Flip_Screen ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_SERVICE( 0x04, IP_ACTIVE_LOW )
+	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Coin_A ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(    0x30, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(    0x20, DEF_STR( 1C_2C ) )
+	PORT_DIPNAME( 0xc0, 0xc0, DEF_STR( Coin_B ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(    0x80, DEF_STR( 1C_2C ) )
 
+	PORT_START_TAG("DSW1")
+	PORT_DIPNAME( 0x01, 0x01, "Enemies" )
+	PORT_DIPSETTING(    0x01, "Few (Easy)" )
+	PORT_DIPSETTING(    0x00, "Many (Hard)" )
+	PORT_DIPNAME( 0x02, 0x02, "Enemy Shots" )
+	PORT_DIPSETTING(    0x02, "Few (Easy)" )
+	PORT_DIPSETTING(    0x00, "Many (Hard)" )
+	PORT_DIPNAME( 0x0c, 0x0c, DEF_STR( Bonus_Life ) )
+	PORT_DIPSETTING(    0x0c, "100K 400K" )
+	PORT_DIPSETTING(    0x08, "200K 400K" )
+	PORT_DIPSETTING(    0x04, "300K 400K" )
+	PORT_DIPSETTING(    0x00, "400K 400K" )
+	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Lives ) )
+	PORT_DIPSETTING(    0x30, "3" )
+	PORT_DIPSETTING(    0x20, "4" )
+	PORT_DIPSETTING(    0x10, "5" )
+	PORT_DIPSETTING(    0x00, "99 (Cheat)")	// 6 in original version
+	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unused ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Language ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( English ) )
+	PORT_DIPSETTING(    0x80, DEF_STR( Japanese ) )
+
+	PORT_START_TAG("IN0")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_TILT )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SERVICE1 )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START_TAG("IN1")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  ) PORT_8WAY
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  ) PORT_8WAY
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    ) PORT_8WAY
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON2 )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START_TAG("IN2")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+INPUT_PORTS_END
 
 static const gfx_layout charlayout =
 {
@@ -706,11 +971,9 @@ static struct YM2203interface ym2203_interface =
 	irqhandler
 };
 
-
-
 static MACHINE_DRIVER_START( tokio )
 	// basic machine hardware
-	MDRV_CPU_ADD(Z80, MAIN_XTAL/4)	// 6 MHz
+	MDRV_CPU_ADD_TAG("main", Z80, MAIN_XTAL/4)	// 6 MHz
 	MDRV_CPU_PROGRAM_MAP(tokio_map, 0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold, 1)
 
@@ -721,7 +984,10 @@ static MACHINE_DRIVER_START( tokio )
 	MDRV_CPU_ADD(Z80, MAIN_XTAL/8)
 	/* audio CPU */	// 3 MHz
 	MDRV_CPU_PROGRAM_MAP(tokio_sound_map, 0) // NMIs are triggered by the main CPU, IRQs are triggered by the YM2203
-
+	
+	MDRV_CPU_ADD_TAG("mcu", M68705, MAIN_XTAL/8)  /* 3 MHz */
+	MDRV_CPU_PROGRAM_MAP(tokio_m68705_readmem,tokio_m68705_writemem)
+	
 	MDRV_FRAMES_PER_SECOND(VSYNC)	// 59.185606 Hz
 	MDRV_VBLANK_DURATION(VBLANK) 	// 2560 us
 	MDRV_INTERLEAVE(100) // 100 CPU slices per frame - a high value to ensure proper synchronization of the CPUs
@@ -746,11 +1012,21 @@ static MACHINE_DRIVER_START( tokio )
 	MDRV_SOUND_ROUTE(3, "mono", 1.0)
 MACHINE_DRIVER_END
 
+static MACHINE_DRIVER_START( tokiob )
+	MDRV_IMPORT_FROM(tokio)
+
+	// basic machine hardware
+	MDRV_CPU_MODIFY("main")
+	MDRV_CPU_PROGRAM_MAP(tokiob_map, 0)
+
+	MDRV_CPU_REMOVE("mcu")
+MACHINE_DRIVER_END
+
 static MACHINE_DRIVER_START( bublbobl )
 	// basic machine hardware
 	MDRV_CPU_ADD_TAG("main", Z80, MAIN_XTAL/4)	// 6 MHz
 	MDRV_CPU_PROGRAM_MAP(master_map, 0)
-	MDRV_CPU_VBLANK_INT(bublbobl_interrupt, 1) // IRQs should be triggered by the MCU, but we don't have it
+	// IRQs are triggered by the MCU
 
 	MDRV_CPU_ADD(Z80, MAIN_XTAL/4)	// 6 MHz
 	MDRV_CPU_PROGRAM_MAP(slave_map, 0)
@@ -760,8 +1036,12 @@ static MACHINE_DRIVER_START( bublbobl )
 	/* audio CPU */	// 3 MHz
 	MDRV_CPU_PROGRAM_MAP(sound_map, 0) // IRQs are triggered by the YM2203
 
+	MDRV_CPU_ADD_TAG("mcu", M6801, 4000000/4)	// actually 6801U4  // xtal is 4MHz, divided by 4 internally
+	MDRV_CPU_PROGRAM_MAP(mcu_map, 0)
+	MDRV_CPU_VBLANK_INT(irq0_line_pulse, 1) // comes from the same clock that latches the INT pin on the second Z80
+
 #if 0
-	// left for reference. The 68705 was from a bootleg, the original MCU is a 68701
+	// left for reference. The 68705 was from a bootleg, the original MCU is a 6801U4
 	MDRV_CPU_ADD_TAG("mcu", M68705, 4000000/2)	// xtal is 4MHz, I think it's divided by 2 internally
 	MDRV_CPU_PROGRAM_MAP(mcu_map, 0)
 	MDRV_CPU_VBLANK_INT(bublbobl_m68705_interrupt, 2) // ??? should come from the same clock which latches the INT pin on the second Z80
@@ -799,7 +1079,7 @@ static MACHINE_DRIVER_START( boblbobl )
 	MDRV_CPU_PROGRAM_MAP(bootleg_map, 0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold, 1)	// interrupt mode 1, unlike Bubble Bobble
 
-//  MDRV_CPU_REMOVE("mcu")
+	MDRV_CPU_REMOVE("mcu")
 MACHINE_DRIVER_END
 
 
@@ -819,8 +1099,8 @@ ROM_START( tokio )
 	ROM_REGION( 0x10000, REGION_CPU3, 0 )	/* audio CPU */
 	ROM_LOAD( "a71-07.10",    0x0000, 0x08000, CRC(f298cc7b) SHA1(ebf5c804aa07b7f198ec3e1f8d1e111cd89ebdf3) )
 
-	ROM_REGION( 0x0800, REGION_CPU4, 0 )	/* 2k for the microcontroller (68705P5) */
-	ROM_LOAD( "a71-24.57",    0x0000, 0x0800, NO_DUMP )
+	ROM_REGION( 0x0800,  REGION_CPU4, 0 )	/* 2k for the microcontroller */
+	ROM_LOAD( "a71__24.ic57", 0x0000, 0x0800, CRC(0f4b25de) SHA1(e2d82aa8d8cc6a86aaf5715ef9cb62f526fd5b11) )
 
 	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
 	ROM_LOAD( "a71-08.12",    0x00000, 0x8000, CRC(0439ab13) SHA1(84142220a6a29f0e34f7c7c751b583bf394df8ce) )    /* 1st plane */
@@ -859,8 +1139,8 @@ ROM_START( tokiou )
 	ROM_REGION( 0x10000, REGION_CPU3, 0 )	/* audio CPU */
 	ROM_LOAD( "a71-07.10",    0x0000, 0x08000, CRC(f298cc7b) SHA1(ebf5c804aa07b7f198ec3e1f8d1e111cd89ebdf3) )
 
-	ROM_REGION( 0x0800, REGION_CPU4, 0 )	/* 2k for the microcontroller (68705P5) */
-	ROM_LOAD( "a71-24.57",    0x0000, 0x0800, NO_DUMP )
+	ROM_REGION( 0x0800,  REGION_CPU4, 0 )	/* 2k for the microcontroller */
+	ROM_LOAD( "a71__24.ic57", 0x0000, 0x0800, CRC(0f4b25de) SHA1(e2d82aa8d8cc6a86aaf5715ef9cb62f526fd5b11) )
 
 	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
 	ROM_LOAD( "a71-08.12",    0x00000, 0x8000, CRC(0439ab13) SHA1(84142220a6a29f0e34f7c7c751b583bf394df8ce) )    /* 1st plane */
@@ -921,7 +1201,7 @@ ROM_START( tokiob )
 	ROM_LOAD( "a71-25.41",    0x0000, 0x0100, CRC(2d0f8545) SHA1(089c31e2f614145ef2743164f7b52ae35bc06808) )	/* video timing */
 ROM_END
 
-// left for reference. The 68705 was from a bootleg, the original MCU is a 68701
+// left for reference. The 68705 was from a bootleg, the original MCU is a 6801U4
 //  ROM_LOAD( "68705.bin",    0x0000, 0x0800, CRC(78caa635) SHA1(a756e45b25b007843ba4f2204cad6081cf7260e9) )    /* from a pirate board */
 
 
@@ -952,8 +1232,8 @@ ROM_START( bublbobl )
 	ROM_REGION( 0x10000, REGION_CPU3, 0 )	/* 64k for the third CPU */
 	ROM_LOAD( "a78-07.46",    0x0000, 0x08000, CRC(4f9a26e8) SHA1(3105b34b88a7134493c2b3f584729f8b0407a011) )
 
-	ROM_REGION( 0x0800, REGION_CPU4, 0 )	/* 2k for the microcontroller */
-	ROM_LOAD( "68701.bin",    0x0000, 0x0800, NO_DUMP )
+	ROM_REGION( 0x10000, REGION_CPU4, 0 )	/* 64k for the MCU */
+	ROM_LOAD( "a78-01.17",    0xf000, 0x1000, CRC(b1bfb53d) SHA1(31b8f31acd3aa394acd80db362774749842e1285) )
 
 	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
 	ROM_LOAD( "a78-09.12",    0x00000, 0x8000, CRC(20358c22) SHA1(2297af6c53d5807bf90a8e081075b8c72a994fc5) )    /* 1st plane */
@@ -995,8 +1275,8 @@ ROM_START( bublbob1 )
 	ROM_REGION( 0x10000, REGION_CPU3, 0 )	/* 64k for the third CPU */
 	ROM_LOAD( "a78-07.46",    0x0000, 0x08000, CRC(4f9a26e8) SHA1(3105b34b88a7134493c2b3f584729f8b0407a011) )
 
-	ROM_REGION( 0x0800, REGION_CPU4, 0 )	/* 2k for the microcontroller */
-	ROM_LOAD( "68701.bin",    0x0000, 0x0800, NO_DUMP )
+	ROM_REGION( 0x10000, REGION_CPU4, 0 )	/* 64k for the MCU */
+	ROM_LOAD( "a78-01.17",    0xf000, 0x1000, CRC(b1bfb53d) SHA1(31b8f31acd3aa394acd80db362774749842e1285) )
 
 	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
 	ROM_LOAD( "a78-09.12",    0x00000, 0x8000, CRC(20358c22) SHA1(2297af6c53d5807bf90a8e081075b8c72a994fc5) )    /* 1st plane */
@@ -1038,8 +1318,8 @@ ROM_START( bublbobr )
 	ROM_REGION( 0x10000, REGION_CPU3, 0 )	/* 64k for the third CPU */
 	ROM_LOAD( "a78-07.46",    0x0000, 0x08000, CRC(4f9a26e8) SHA1(3105b34b88a7134493c2b3f584729f8b0407a011) )
 
-	ROM_REGION( 0x0800, REGION_CPU4, 0 )	/* 2k for the microcontroller */
-	ROM_LOAD( "68701.bin",    0x0000, 0x0800, NO_DUMP )
+	ROM_REGION( 0x10000, REGION_CPU4, 0 )	/* 64k for the MCU */
+	ROM_LOAD( "a78-01.17",    0xf000, 0x1000, CRC(b1bfb53d) SHA1(31b8f31acd3aa394acd80db362774749842e1285) )
 
 	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
 	ROM_LOAD( "a78-09.12",    0x00000, 0x8000, CRC(20358c22) SHA1(2297af6c53d5807bf90a8e081075b8c72a994fc5) )    /* 1st plane */
@@ -1081,8 +1361,8 @@ ROM_START( bubbobr1 )
 	ROM_REGION( 0x10000, REGION_CPU3, 0 )	/* 64k for the third CPU */
 	ROM_LOAD( "a78-07.46",    0x0000, 0x08000, CRC(4f9a26e8) SHA1(3105b34b88a7134493c2b3f584729f8b0407a011) )
 
-	ROM_REGION( 0x0800, REGION_CPU4, 0 )	/* 2k for the microcontroller */
-	ROM_LOAD( "68701.bin",    0x0000, 0x0800, NO_DUMP )
+	ROM_REGION( 0x10000, REGION_CPU4, 0 )	/* 64k for the MCU */
+	ROM_LOAD( "a78-01.17",    0xf000, 0x1000, CRC(b1bfb53d) SHA1(31b8f31acd3aa394acd80db362774749842e1285) )
 
 	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
 	ROM_LOAD( "a78-09.12",    0x00000, 0x8000, CRC(20358c22) SHA1(2297af6c53d5807bf90a8e081075b8c72a994fc5) )    /* 1st plane */
@@ -1173,6 +1453,69 @@ ROM_START( sboblbob )
 ROM_END
 
 
+ROM_START( bublboblu )
+	ROM_REGION( 0x30000, REGION_CPU1, 0 )
+	ROM_LOAD( "a78-06u.51",    0x00000, 0x08000, CRC(a6345edd) SHA1(144f33002ee40acdbfa6a49119092a319048bb00) )
+	ROM_LOAD( "a78-05u.52",    0x10000, 0x10000, CRC(b31d2edc) SHA1(b7d317c0b5b86c0bf39b18cfe584bca9d22d4eba) )
+
+	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_LOAD( "a78-08u.37",    0x0000, 0x08000, CRC(d544be2e) SHA1(1472db52dcd9e17a866ea2766cfea500d8f712ab) )
+
+	ROM_REGION( 0x10000, REGION_CPU3, 0 )
+	ROM_LOAD( "a78-07.46",    0x0000, 0x08000, CRC(4f9a26e8) SHA1(3105b34b88a7134493c2b3f584729f8b0407a011) )
+
+	ROM_REGION( 0x10000, REGION_CPU4, 0 )
+	ROM_LOAD( "a78-01.17",    0xf000, 0x1000, CRC(b1bfb53d) SHA1(31b8f31acd3aa394acd80db362774749842e1285) )
+
+	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
+	ROM_LOAD( "a78-09.12",    0x00000, 0x8000, CRC(20358c22) SHA1(2297af6c53d5807bf90a8e081075b8c72a994fc5) )
+	ROM_LOAD( "a78-10.13",    0x08000, 0x8000, CRC(930168a9) SHA1(fd358c3c3b424bca285f67a1589eb98a345ff670) )
+	ROM_LOAD( "a78-11.14",    0x10000, 0x8000, CRC(9773e512) SHA1(33c1687ee575d66bf0e98add45d06da827813765) )
+	ROM_LOAD( "a78-12.15",    0x18000, 0x8000, CRC(d045549b) SHA1(0c12077d3ddc2ce6aa45a0224ad5540f3f218446) )
+	ROM_LOAD( "a78-13.16",    0x20000, 0x8000, CRC(d0af35c5) SHA1(c5a89f4d73acc0db86654540b3abfd77b3757db5) )
+	ROM_LOAD( "a78-14.17",    0x28000, 0x8000, CRC(7b5369a8) SHA1(1307b26d80e6f36ebe6c442bebec41d20066eaf9) )
+	ROM_LOAD( "a78-15.30",    0x40000, 0x8000, CRC(6b61a413) SHA1(44eddf12fb46fceca2addbe6da929aaea7636b13) )
+	ROM_LOAD( "a78-16.31",    0x48000, 0x8000, CRC(b5492d97) SHA1(d5b045e3ebaa44809757a4220cefb3c6815470da) )
+	ROM_LOAD( "a78-17.32",    0x50000, 0x8000, CRC(d69762d5) SHA1(3326fef4e0bd86681a3047dc11886bb171ecb609) )
+	ROM_LOAD( "a78-18.33",    0x58000, 0x8000, CRC(9f243b68) SHA1(32dce8d311a4be003693182a999e4053baa6bb0a) )
+	ROM_LOAD( "a78-19.34",    0x60000, 0x8000, CRC(66e9438c) SHA1(b94e62b6fbe7f4e08086d0365afc5cff6e0ccafd) )
+	ROM_LOAD( "a78-20.35",    0x68000, 0x8000, CRC(9ef863ad) SHA1(29f91b5a3765e4d6e6c3382db1d8d8297b6e56c8) )
+
+	ROM_REGION( 0x0100, REGION_PROMS, 0 )
+	ROM_LOAD( "a71-25.41",    0x0000, 0x0100, CRC(2d0f8545) SHA1(089c31e2f614145ef2743164f7b52ae35bc06808) )
+ROM_END
+
+ROM_START( bublcave )
+	ROM_REGION( 0x30000, REGION_CPU1, 0 )
+	ROM_LOAD( "bublcave-06.51",    0x00000, 0x08000, CRC(e8b9af5e) SHA1(dec44e47634a402df212806e84e3a810f8442776) )
+	ROM_LOAD( "bublcave-05.52",    0x10000, 0x10000, CRC(cfe14cb8) SHA1(17d463c755f630ae9d05943515fa4828972bd7b0) )
+
+	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_LOAD( "bublcave-08.37",    0x0000, 0x08000, CRC(a9384086) SHA1(26e686671d6d3ba3759716bf46e7f951bbb8a291) )
+
+	ROM_REGION( 0x10000, REGION_CPU3, 0 )
+	ROM_LOAD( "a78-07.46",         0x0000, 0x08000, CRC(4f9a26e8) SHA1(3105b34b88a7134493c2b3f584729f8b0407a011) )
+
+	ROM_REGION( 0x10000, REGION_CPU4, 0 )
+	ROM_LOAD( "a78-01.17",         0xf000, 0x1000, CRC(b1bfb53d) SHA1(31b8f31acd3aa394acd80db362774749842e1285) )
+
+	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
+	ROM_LOAD( "bublcave-09.12",    0x00000, 0x8000, CRC(b90b7eef) SHA1(de72e4635843ad76248aa3b4aa8f8a0bfd53879e) )    /* 1st plane */
+	ROM_LOAD( "bublcave-10.13",    0x08000, 0x8000, CRC(4fb22f05) SHA1(880104e86dbd00ae657cbc768722427503b6a59f) )
+	ROM_LOAD( "bublcave-11.14",    0x10000, 0x8000, CRC(9773e512) SHA1(33c1687ee575d66bf0e98add45d06da827813765) )
+	ROM_LOAD( "bublcave-12.15",    0x18000, 0x8000, CRC(e49eb49e) SHA1(2e05dc8833e10bef1a317d238c39fb9f362e9997) )
+	ROM_LOAD( "bublcave-13.16",    0x20000, 0x8000, CRC(61919734) SHA1(2c07e29f3dcc972d5eb47679ad81a0d7656b0cb2) )
+	ROM_LOAD( "bublcave-14.17",    0x28000, 0x8000, CRC(7e3a13bd) SHA1(bd4dba799340fa599f11cc68e03efe70ba6ba99b) )
+	ROM_LOAD( "bublcave-15.30",    0x40000, 0x8000, CRC(c253c73a) SHA1(3e187f6b9ca769772990068abe7b309417147d39) )    /* 2nd plane */
+	ROM_LOAD( "bublcave-16.31",    0x48000, 0x8000, CRC(e66c92ee) SHA1(12ea193c54121d08ad110c94cc075e29fef3ff85) )
+	ROM_LOAD( "bublcave-17.32",    0x50000, 0x8000, CRC(d69762d5) SHA1(3326fef4e0bd86681a3047dc11886bb171ecb609) )
+	ROM_LOAD( "bublcave-18.33",    0x58000, 0x8000, CRC(47ee2544) SHA1(c6946e824043a312ed437e548a64ef599effbd42) )
+	ROM_LOAD( "bublcave-19.34",    0x60000, 0x8000, CRC(1ceeb1fa) SHA1(eb29ff896d149f7ab4cf38a338df39df14ccc20c) )
+	ROM_LOAD( "bublcave-20.35",    0x68000, 0x8000, CRC(64322e24) SHA1(acff8a9fcaf74f198653080759898d15cccf04e8) )
+
+	ROM_REGION( 0x0100, REGION_PROMS, 0 )
+	ROM_LOAD( "a71-25.41",         0x0000, 0x0100, CRC(2d0f8545) SHA1(089c31e2f614145ef2743164f7b52ae35bc06808) )   /* video timing */
+ROM_END
 
 static DRIVER_INIT( bublbobl )
 {
@@ -1192,18 +1535,11 @@ static DRIVER_INIT( tokio )
 	bublbobl_video_enable = 1;
 }
 
-static DRIVER_INIT( tokiob )
-{
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xfe00, 0xfe00, 0, 0, tokiob_mcu_r );
-
-	init_tokio();
-}
 
 
-
-GAME( 1986, tokio,    0,        tokio,    tokio,    tokio,    ROT90, "Taito Corporation", "Tokio / Scramble Formation", GAME_NOT_WORKING )
-GAME( 1986, tokiou,   tokio,    tokio,    tokio,    tokio,    ROT90, "Taito America Corporation (Romstar license)", "Tokio / Scramble Formation (US)", GAME_NOT_WORKING )
-GAME( 1986, tokiob,   tokio,    tokio,    tokio,    tokiob,   ROT90, "bootleg", "Tokio / Scramble Formation (bootleg)", 0 )
+GAME( 1986, tokio,    0,        tokio,    tokio,    tokio,    ROT90, "Taito Corporation", "Tokio / Scramble Formation", 0 )
+GAME( 1986, tokiou,   tokio,    tokio,    tokio,    tokio,    ROT90, "Taito America Corporation (Romstar license)", "Tokio / Scramble Formation (US)", 0 )
+GAME( 1986, tokiob,   tokio,    tokiob,   tokiob,   tokio,    ROT90, "bootleg", "Tokio / Scramble Formation (bootleg)", 0 )
 
 GAME( 1986, bublbobl, 0,        bublbobl, bublbobl, bublbobl, ROT0,  "Taito Corporation", "Bubble Bobble", 0 )
 GAME( 1986, bublbob1, bublbobl, bublbobl, bublbobl, bublbobl, ROT0,  "Taito Corporation", "Bubble Bobble (older)", 0 )
@@ -1212,3 +1548,8 @@ GAME( 1986, bubbobr1, bublbobl, bublbobl, bublbobl, bublbobl, ROT0,  "Taito Amer
 
 GAME( 1986, boblbobl, bublbobl, boblbobl, boblbobl, bublbobl, ROT0,  "bootleg", "Bobble Bobble", 0 )
 GAME( 1986, sboblbob, bublbobl, boblbobl, sboblbob, bublbobl, ROT0,  "bootleg", "Super Bobble Bobble", 0 )
+
+/* hacks */
+GAME( 2012, bublboblu,bublbobl, bublbobl, bublbobl, bublbobl, ROT0,  "bootleg", "Bubble Bobble (Ultra Version)(USA)", 0 )
+GAME( 2013, bublcave, bublbobl, bublbobl, bublbobl, bublbobl, ROT0,  "bootleg", "Bubble Bobble : Lost Cave V1.2", 0 )
+
