@@ -1861,124 +1861,6 @@ ROM_END
 
 /*
 
-Denjin Makai
-Banpresto, 1994
-
-This game runs on early 90's Seibu hardware.
-(i.e. Raiden II, Godzilla, Seibu Cup Soccer, Legionairre, Heated Barrel etc).
-The PCB looks to have been converted from some other game (a lot of flux traces are
-left on the PCB). The game might be a simple ROM swap for some other Seibu-based game.
-
-
-PCB Layout
-----------
-
-|-----------------------------------------------------|
-|LA4460   YM2151   M6295  ROM6  ROM5  Z80       PAL6  |
-|                                     6116      PAL9  |
-|        SEI0100BU   SEI0220BP  14.31818MHz           |
-|                                                     |
-|        6116                                         |
-|                              OBJ-0-3     OBJ-6-7    |
-|J       6116      SEI0211                            |
-|A                             OBJ-4-5     OBJ-8-9    |
-|M                                                    |
-|M                        ROM1     ROM3      62256    |
-|M                                           62256    |
-|                         ROM2     ROM4      62256    |
-|     DSW1   S68E08  PAL7                    62256    |
-|     DSW2                PAL6  PAL3                  |
-|SEI0200                                              |
-|     6264                                            |
-|     6264                   COPX-D2                  |
-|                                             SEI1000 |
-|BG-1-AB            ROM7         PAL2  PAL1           |
-|                                                     |
-|BG-2-AB   BG-3-AB  ROM8  20MHz  PAL5  68000          |
-|-----------------------------------------------------|
-Notes:
-      68000 clock  : 10.000MHz (20 / 2)
-      Z80 clock    : 3.579545MHz (14.31818 / 4)
-      YM2151 clock : 3.579545MHz (14.31818 / 4)
-      M6295 clock  : 1.000MHz, sample rate = M6295 clock / 132
-      VSync        : 56Hz
-
-      62256    : 32K x8 SRAM
-      6264     : 8K  x8 SRAM
-      6116     : 2K  x8 SRAM
-      SEI0200  : Custom Seibu QFP100 also stamped TC110G21AF
-      SEI1000  : Custom Seibu QFP184 also stamped SB01-001
-      SEI0211  : Custom Seibu QFP128
-      SEI0100BU: Custom Seibu SDIP64 also stamped YM3931
-      SEI0220BP: Custom Seibu QFP80
-
-      ROMs 1, 2, 3, 4   Main program   27C020 EPROM
-      ROM  6            OKI samples    27C020 EPROM
-      ROM  5            Sound program  27C512 EPROM
-      ROMs 7 and 8      Graphics       27C512 EPROM
-      ROMs BG*          Graphics       8M Mask ROM
-      ROMs OBJ*         Graphics       8M Mask ROM
-      COPX-D2           ?              4M Mask ROM
-
-      PAL1 : type AMI 18CV8PC,    labelled 'S68E01'
-      PAL2 : type MMI PAL16L8ACN, labelled 'S68E02'
-      PAL3 : type MMI PAL16L8ACN, labelled 'S68E03'
-      PAL4 : type AMI 18CV8PC,    labelled 'S68E04'
-      PAL5 : type AMI 18CV8PC,    labelled 'S68E05T'
-      PAL6 : type AMI 18CV8PC,    labelled 'S68E06T'
-      PAL7 : type AMI 18CV8PC,    labelled 'S68E07'
-      PAL9 : type MMI PAL16L8ACN, labelled 'S68E09'
-
-      S68E08 : PROM type 82S147, labelled 'S68E08'
-
-
-*/
-
-ROM_START( denjinmk )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )	/* 68000 code */
-	ROM_LOAD32_BYTE( "rom1.025",        0x000000, 0x040000, CRC(44a648e8) SHA1(a3c1721e89ac6b9fc16f80682b2f701cb24b5d76) )
-	ROM_LOAD32_BYTE( "rom2.024",        0x000001, 0x040000, CRC(e5ee8fe0) SHA1(2ebff4fdbe82062fb526598e10f11358b0b5c02f) )
-	ROM_LOAD32_BYTE( "rom3.026",        0x000002, 0x040000, CRC(781b942e) SHA1(f1f4ddc332de3dc29b716a1b82c2ecc2045efb3a) )
-	ROM_LOAD32_BYTE( "rom4.023",        0x000003, 0x040000, CRC(502a588b) SHA1(9055b631240fe52d33b572e34275d31a9f3d290f) )
-
-	ROM_REGION( 0x20000*2, REGION_CPU2, 0 )	/* Z80 code, banked data */
-	ROM_LOAD( "rom5.016",        0x000000, 0x08000, CRC(7fe7e352) SHA1(1ceae22186751ca91dfffab7bd11f275e693451f) )
-	ROM_CONTINUE(			  0x010000, 0x08000 )	/* banked stuff */
-
-	ROM_REGION( 0x020000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "rom7.620",       0x000000, 0x010000, CRC(e1f759b1) SHA1(ddc60e78e7791a59c59403dd4089b3f6e1ecf8cb) )
-	ROM_LOAD( "rom8.615",       0x010000, 0x010000, CRC(cc36af0d) SHA1(69c2ae38f03be79be4d138fcc73a6a86407eb285) )
-
-	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_DISPOSE )
-	ROM_LOAD( "obj-0-3.748",     0x000000, 0x100000, CRC(3dcc7b04) SHA1(3c3ad5ddc18a42046348dcb54e65f6173c003d72) )
-	ROM_LOAD( "obj-4-5.756",     0x100000, 0x100000, CRC(01f8d4e6) SHA1(25b69da693be8c3404f750b419c330a7a56e88ec) )
-	ROM_LOAD( "obj-6-7.743",     0x200000, 0x100000, CRC(e5805757) SHA1(9d392c27eef7c1fcda560dac17ba9d7ae2287ac8) )
-	ROM_LOAD( "obj-8-9.757",     0x300000, 0x100000, CRC(c8f7e1c9) SHA1(a746d187b50a0ecdd5a7f687a2601e5dc8bfe272) )
-
-	ROM_REGION( 0x100000, REGION_GFX3, ROMREGION_DISPOSE )	/* MBK tiles */
-	ROM_LOAD( "bg-1-ab.618",      0x000000, 0x100000, CRC(eaad151a) SHA1(bdd1d83ee8497efe20f21baf873e786446372bcb) )
-
-	ROM_REGION( 0x100000, REGION_GFX4, ROMREGION_DISPOSE )	/* BK2 used */
-	ROM_LOAD( "bg-2-ab.617",      0x000000, 0x100000, CRC(40938f74) SHA1(d68b0f8245a8b390ad5d4e6ebc7514a939b8ac51) )
-
-	ROM_REGION( 0x100000, REGION_GFX5, ROMREGION_DISPOSE )	/* BK3 tiles */
-	ROM_LOAD( "bg-3-ab.619",      0x000000, 0x100000,  CRC(de7366ee) SHA1(0c3969d15f3cd963e579d4164b6e0a6b4012c9c6) )
-
-	ROM_REGION( 0x100000, REGION_GFX6, ROMREGION_DISPOSE )	/* LBK tiles */
-	ROM_COPY( REGION_GFX3, 0x00000, 0x00000, 0x100000 )
-
-	ROM_REGION( 0x080000, REGION_SOUND1, 0 )	/* ADPCM samples */
-	ROM_LOAD( "rom6.922",      0x000000, 0x040000, CRC(09e13213) SHA1(9500e057104c6b83da0467938e46d9efa2f49f4c) )
-
-	ROM_REGION( 0x200, REGION_PROMS, 0 )
-	ROM_LOAD( "s68e08.844",   0x000000, 0x000200, CRC(96f7646e) SHA1(400a831b83d6ac4d2a46ef95b97b1ee237099e44) ) /* Priority */
-
-	ROM_REGION( 0x080000, REGION_USER1, 0 )
-	ROM_LOAD( "copx-d2.313",  0x000000, 0x080000, CRC(7c52581b) SHA1(7e668476f886806b0c06fa0bcf4bbc955878c87c) )
-ROM_END
-
-/*
-
 SD Gundam Sangokushi Rainbow Tairiku Senki
 (c)1993 Banpresto
 TYPE-R
@@ -2198,7 +2080,6 @@ GAME( 1992, heatbrlo, heatbrl,  heatbrl,  heatbrl,  0,        ROT0, "Tad", "Heat
 GAME( 1992, heatbrlu, heatbrl,  heatbrl,  heatbrl,  0,        ROT0, "Tad", "Heated Barrel (US)", GAME_UNEMULATED_PROTECTION | GAME_NOT_WORKING )
 
 GAME( 1993, godzilla, 0,        godzilla, godzilla, 0,        ROT0, "Banpresto", "Godzilla", GAME_UNEMULATED_PROTECTION | GAME_NOT_WORKING )
-GAME( 1993, denjinmk, 0,        godzilla, godzilla, 0,        ROT0, "Banpresto", "Denjin Makai", GAME_UNEMULATED_PROTECTION | GAME_NOT_WORKING )
 GAME( 1993, sdgndmrb, 0,        sdgndmrb, sdgndmrb, 0,	       ROT0, "Banpresto", "SD Gundam Sangokushi Rainbow Tairiku Senki", GAME_UNEMULATED_PROTECTION | GAME_NOT_WORKING )
 
 GAME( 1992, cupsoc,   0,        cupsoc,  cupsoc,    0,        ROT0, "Seibu", "Seibu Cup Soccer", GAME_UNEMULATED_PROTECTION | GAME_NOT_WORKING )
