@@ -98,6 +98,7 @@
 
 /* internal states */
 static UINT8 		misc_io_data[0x10];	/* holds values written to the I/O chip */
+static UINT8 		misc_io_data_override = 0;
 
 /* protection-related tracking */
 static const UINT32 *prot_table;		/* table of protection values */
@@ -398,6 +399,52 @@ static READ16_HANDLER( io_chip_r )
 	return 0xffff;
 }
 
+static READ16_HANDLER( tfrceacjpb_io_chip_r )
+{
+	offset &= 0x1f/2;
+
+	switch (offset)
+	{
+		/* I/O ports */
+		case 0x00/2:
+		case 0x02/2:
+		case 0x04/2:
+		case 0x06/2:
+		case 0x08/2:
+		case 0x0a/2:
+		case 0x0c/2:
+		case 0x0e/2:
+			/* if the port is configured as an output, return the last thing written */
+			if (misc_io_data_override & misc_io_data[0x1e/2] & (1 << offset))
+				return misc_io_data[offset];
+
+			/* otherwise, return an input port */
+			if (offset == 0x04/2 && sound_banks)
+				return (readinputport(offset) & 0xbf) | (upd7759_0_busy_r(0) << 6);
+			return readinputport(offset);
+
+		/* 'SEGA' protection */
+		case 0x10/2:
+			return 'S';
+		case 0x12/2:
+			return 'E';
+		case 0x14/2:
+			return 'G';
+		case 0x16/2:
+			return 'A';
+
+		/* CNT register & mirror */
+		case 0x18/2:
+		case 0x1c/2:
+			return misc_io_data[0x1c/2];
+
+		/* port direction register & mirror */
+		case 0x1a/2:
+		case 0x1e/2:
+			return misc_io_data[0x1e/2];
+	}
+	return 0xffff;
+}
 
 static WRITE16_HANDLER( io_chip_w )
 {
@@ -659,7 +706,18 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xe00000, 0xe0ffff) AM_MIRROR(0x1f0000) AM_RAM AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)
 ADDRESS_MAP_END
 
-
+static ADDRESS_MAP_START( tfrceacjpb_main_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x1fffff) AM_ROM
+	AM_RANGE(0x800000, 0x800001) AM_MIRROR(0x13fdfe) AM_READWRITE(prot_r, prot_w)
+	AM_RANGE(0x800200, 0x800201) AM_MIRROR(0x13fdfe) AM_WRITE(control_w)
+	AM_RANGE(0x840000, 0x84001f) AM_MIRROR(0x13fee0) AM_READWRITE(tfrceacjpb_io_chip_r, io_chip_w)
+	AM_RANGE(0x840100, 0x840107) AM_MIRROR(0x13fef8) AM_READWRITE(ym3438_r, ym3438_w)
+	AM_RANGE(0x880000, 0x880001) AM_MIRROR(0x13fefe) AM_WRITE(segac2_upd7759_w)
+	AM_RANGE(0x880100, 0x880101) AM_MIRROR(0x13fefe) AM_WRITE(counter_timer_w)
+	AM_RANGE(0x8c0000, 0x8c0fff) AM_MIRROR(0x13f000) AM_READWRITE(palette_r, palette_w) AM_BASE(&paletteram16)
+	AM_RANGE(0xc00000, 0xc0001f) AM_MIRROR(0x18ff00) AM_READWRITE(genesis_vdp_r, genesis_vdp_w)
+	AM_RANGE(0xe00000, 0xe0ffff) AM_MIRROR(0x1f0000) AM_RAM AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)
+ADDRESS_MAP_END
 
 /******************************************************************************
     Input Ports
@@ -1432,7 +1490,19 @@ static MACHINE_DRIVER_START( segac2 )
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
+static MACHINE_DRIVER_START( tfrceacjpb )
 
+	/* basic machine hardware */
+	MDRV_IMPORT_FROM( segac )
+	
+	MDRV_CPU_MODIFY("main")
+	MDRV_CPU_PROGRAM_MAP(tfrceacjpb_main_map,0)
+
+	/* sound hardware */
+	MDRV_SOUND_ADD(UPD7759, XL1_CLOCK)
+	MDRV_SOUND_CONFIG(upd7759_intf)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_DRIVER_END
 
 /******************************************************************************
     Rom Definitions
@@ -1569,6 +1639,21 @@ ROM_START( tfrceacb ) /* ThunderForce AC (Bootleg)  (c)1990 Technosoft / Sega */
 	ROM_LOAD( "ic4.bin", 0x000000, 0x040000, CRC(e09961f6) SHA1(e109b5f41502b765d191f22e3bbcff97d6defaa1) )
 ROM_END
 
+/* This set has significantly different code addresses to both the Genesis Thunder Force III and the arcade Thunder Force AC, and seems to sit somewhere between them
+   Some sources indicate it's a hack, but it might be a hack of an otherwise unsupported set, with the protection removed, for bootleggers to sell at a profit.
+   This specific dump was sourced from a PCB sold in Canada 
+*/
+ROM_START( tfrceacjpb ) /* protection chip simply marked T-FORCE (not used outside of startup init?) */
+	ROM_REGION( 0x200000, REGION_CPU1, ROMREGION_ERASEFF )
+	ROM_LOAD16_BYTE( "ic32_t.f.ac_075f.ic32", 0x000000, 0x040000, CRC(2167dd93) SHA1(0e5b8eb87e07e6e5cecf096e6b62e15ff7406bba) )
+	ROM_LOAD16_BYTE( "ic31_t.f.ac_0d26.id31", 0x000001, 0x040000, CRC(ebf02bba) SHA1(effdc60837063ba04b7b4517e57a240b29a199e1) )
+	/* 0x080000 - 0x100000 Empty */
+	ROM_LOAD16_BYTE( "ic34_t.f.ac_549d.ic34", 0x100000, 0x040000, CRC(902ad2ec) SHA1(58db20ca5888110e97f80e7df9dac1b8e9817562) )
+	ROM_LOAD16_BYTE( "ic33_t.f.ac_d131.ic33", 0x100001, 0x040000, CRC(b162219d) SHA1(ad022307019b4a70cb532e1101cb5ed8d31f10e2) )
+
+	ROM_REGION( 0x040000, REGION_SOUND1, ROMREGION_ERASE00 )
+	/* empty socket (not used) */
+ROM_END
 
 ROM_START( twinsqua ) /* Twin Squash  (c)1991 Sega */
 	ROM_REGION( 0x200000, REGION_CPU1, 0 )
@@ -1954,6 +2039,23 @@ static DRIVER_INIT( tfrceacb )
 	memory_install_write16_handler(0, ADDRESS_SPACE_PROGRAM, 0x800000, 0x800001, 0, 0, MWA16_NOP);
 }
 
+static DRIVER_INIT( tfrceacjpb )
+{
+	static const UINT32 table[256/8] =
+	{
+		0x3a3a6f6f, 0x38386d6d, 0x3a3a6f6f, 0x28287d7d,
+		0x3a3a6f6f, 0x38386d6d, 0x3a3a6f6f, 0x28287d7d,
+		0x7e3a2b6f, 0x7c38296d, 0x7eb22be7, 0x6ca039f5,
+		0x7e3a2b6f, 0x7c38296d, 0x7eb22be7, 0x6ca039f5,
+		0x3b3b6e6e, 0x39396c6c, 0x5dd50880, 0x4ec61b93,
+		0x3b3b6e6e, 0x39396c6c, 0x3bb36ee6, 0x28a07df5,
+		0x5d19084c, 0x5d19084c, 0x7ff72aa2, 0x6ee63bb3,
+		0x5d19084c, 0x5d19084c, 0x5d9108c4, 0x4c8019d5
+	};
+	segac2_common_init(table);
+	misc_io_data_override = 0xf; // issue w/io chip
+}
+
 
 static DRIVER_INIT( twinsqua )
 {
@@ -2298,6 +2400,7 @@ GAME( 1990, borench,  0,        segac2,   borench,  borench,  ROT0, "Sega",
 GAME( 1990, tfrceac,  0,        segac2,   tfrceac,  tfrceac,  ROT0, "Sega / Technosoft",      "ThunderForce AC", 0 )
 GAME( 1990, tfrceacj, tfrceac,  segac2,   tfrceac,  tfrceac,  ROT0, "Sega / Technosoft",      "ThunderForce AC (Japan)", 0 )
 GAME( 1990, tfrceacb, tfrceac,  segac2,   tfrceac,  tfrceacb, ROT0, "bootleg",                "ThunderForce AC (bootleg)", 0 )
+GAME( 1990, tfrceacjpb,tfrceac, tfrceacjpb,tfrceac, tfrceacjpb, ROT0, "Sega / Technosoft",    "ThunderForce AC (Japan, prototype, bootleg)", 0 )
 GAME( 1991, twinsqua, 0,        segac2,   twinsqua, twinsqua, ROT0, "Sega",                   "Twin Squash", 0 )
 GAME( 1991, ribbit,   0,        segac2,   ribbit,   ribbit,   ROT0, "Sega",                   "Ribbit!", 0 )
 GAME( 1992, ooparts,  0,        segac2,   ooparts,  c2boot,   ROT270, "Sega / Success",       "OOPArts (Japan, Prototype)", 0 )
