@@ -644,7 +644,7 @@ static INPUT_PORTS_START( shangupb )
 	PORT_INCLUDE( hangon )
 
 	PORT_MODIFY("SERVICE")
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_CODE(KEYCODE_SPACE)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON3 )
 
 	PORT_MODIFY("COINAGE")
 	PORT_DIPNAME( 0x18, 0x18, "Time Adj." )
