@@ -524,7 +524,7 @@ static MACHINE_DRIVER_START( st0016 )
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(48*8, 48*8)
-	MDRV_VISIBLE_AREA(0*8, 48*8-1, 0*8, 48*8-1)
+	MDRV_VISIBLE_AREA(7*8, (48-7)*8+2, 9*8-2, (48-9)*8-1-2)
 	MDRV_GFXDECODE(gfxdecodeinfo)
 	MDRV_PALETTE_LENGTH(16*16*4+1)
 
