@@ -597,7 +597,7 @@ static MACHINE_DRIVER_START( wilytowr )
 	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(i8039_readmem,i8039_writemem)
 	MDRV_CPU_IO_MAP(i8039_readport,i8039_writeport)
-	MDRV_CPU_PERIODIC_INT(snd_irq, 60)
+	MDRV_CPU_PERIODIC_INT(snd_irq,TIME_IN_HZ(60))
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
@@ -635,7 +635,7 @@ static MACHINE_DRIVER_START( atomboy )
 	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(i8039_readmem,i8039_writemem)
 	MDRV_CPU_IO_MAP(i8039_readport,i8039_writeport)
-	MDRV_CPU_PERIODIC_INT(snd_irq, 60/2)
+	MDRV_CPU_PERIODIC_INT(snd_irq,TIME_IN_HZ(60/2))
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
@@ -672,7 +672,7 @@ static MACHINE_DRIVER_START( fghtbskt )
 	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(i8039_readmem,i8039_writemem)
 	MDRV_CPU_IO_MAP(i8039_readport,i8039_writeport)
-    MDRV_CPU_PERIODIC_INT(snd_irq, 60/2)
+        MDRV_CPU_PERIODIC_INT(snd_irq,TIME_IN_HZ(60/2))
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
