@@ -10,7 +10,7 @@ VIDEO_START( psikyosh );
 VIDEO_UPDATE( psikyosh );
 VIDEO_EOF( psikyosh );
 
-enum { EEPROM_0=0, EEPROM_DEFAULT=1, EEPROM_DARAKU, EEPROM_S1945III, EEPROM_DRAGNBLZ, EEPROM_GNBARICH, EEPROM_USER1 };
+enum { EEPROM_0=0, EEPROM_DEFAULT=1, EEPROM_DARAKU, EEPROM_S1945III, EEPROM_DRAGNBLZ, EEPROM_GNBARICH, EEPROM_TGM2 };
 
 /* Psikyo PS6406B */
 #define FLIPSCREEN (((psikyosh_vidregs[3] & 0x0000c000) == 0x0000c000) ? 1:0)
