@@ -347,11 +347,12 @@ static void print_game_bios(FILE* out, const game_driver* game)
 	}
 }
 
-static void print_game_rom(FILE* out, const game_driver* game)
+static void print_game_rom(FILE* out, int bare, const game_driver* game)
 {
 	const rom_entry *region, *rom, *chunk;
 	const rom_entry *pregion, *prom, *fprom=NULL;
 	const game_driver *clone_of;
+	unsigned rom_bare_size = 0;
 
 	if (!game->rom)
 		return;
@@ -386,6 +387,10 @@ static void print_game_rom(FILE* out, const game_driver* game)
 						}
 			}
 
+			if (bare && in_parent) {
+				continue;
+			}
+
 			found_bios = 0;
 			if(!is_disk && is_bios && game->bios)
 			{
@@ -405,6 +410,11 @@ static void print_game_rom(FILE* out, const game_driver* game)
 			}
 
 
+			if (bare) {
+				rom_bare_size += length;
+				continue;
+			}
+
 			if (!is_disk)
 				fprintf(out, "\t\t<rom");
 			else
@@ -493,6 +503,10 @@ static void print_game_rom(FILE* out, const game_driver* game)
 			fprintf(out, "/>\n");
 		}
 	}
+
+	if (bare && rom_bare_size) {
+		fprintf(out, "\t\t<rom size=\"%u\"/>\n", rom_bare_size);
+	}
 }
 
 static void print_game_sampleof(FILE* out, const game_driver* game)
@@ -716,9 +730,9 @@ static void print_game_driver(FILE* out, const game_driver* game)
 	/* some minor issues, games marked as status=preliminary */
 	/* don't work or have major emulation problems. */
 
-	if (game->flags & (GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_NO_SOUND | GAME_WRONG_COLORS))
+	if (game->flags & (GAME_NOT_WORKING | GAME_NO_SOUND | GAME_WRONG_COLORS))
 		fprintf(out, " status=\"preliminary\"");
-	else if (game->flags & (GAME_IMPERFECT_COLORS | GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS))
+	else if (game->flags & (GAME_IMPERFECT_COLORS | GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS | GAME_UNEMULATED_PROTECTION))
 		fprintf(out, " status=\"imperfect\"");
 	else
 		fprintf(out, " status=\"good\"");
@@ -764,7 +778,7 @@ static void print_game_driver(FILE* out, const game_driver* game)
 }
 
 /* Print the MAME info record for a game */
-static void print_game_info(FILE* out, const game_driver* game)
+static void print_game_info(FILE* out, int bare, const game_driver* game)
 {
 	const char *start;
 	const game_driver *clone_of;
@@ -782,7 +796,8 @@ static void print_game_info(FILE* out, const game_driver* game)
 		start = strrchr(game->source_file, '\\');
 	if (!start)
 		start = game->source_file - 1;
-	fprintf(out, " sourcefile=\"%s\"", normalize_string(start + 1));
+	if (!bare)
+		fprintf(out, " sourcefile=\"%s\"", normalize_string(start + 1));
 
 	clone_of = driver_get_clone(game);
 	if (clone_of && !(clone_of->flags & NOT_A_DRIVER))
@@ -805,18 +820,25 @@ static void print_game_info(FILE* out, const game_driver* game)
 	if (game->manufacturer)
 		fprintf(out, "\t\t<manufacturer>%s</manufacturer>\n", normalize_string(game->manufacturer));
 
-	print_game_bios(out, game);
-	print_game_rom(out, game);
-	print_game_sample(out, game);
-	print_game_micro(out, game);
+	if (!bare)
+		print_game_bios(out, game);
+	print_game_rom(out, bare, game);
+	if (!bare)
+		print_game_sample(out, game);
+	if (!bare)
+		print_game_micro(out, game);
 	print_game_video(out, game);
-	print_game_sound(out, game);
-	print_game_input(out, game);
-	print_game_switch(out, game);
+	if (!bare)
+		print_game_sound(out, game);
+	if (!bare)
+		print_game_input(out, game);
+	if (!bare)
+		print_game_switch(out, game);
 	print_game_driver(out, game);
 #ifdef MESS
 	print_game_device(out, game);
-	print_game_ramoptions(out, game);
+	if (!bare)
+		print_game_ramoptions(out, game);
 #endif
 
 	fprintf(out, "\t</" XML_TOP ">\n");
@@ -824,7 +846,7 @@ static void print_game_info(FILE* out, const game_driver* game)
 
 #if !defined(MESS)
 /* Print the resource info */
-static void print_resource_info(FILE* out, const game_driver* game)
+static void print_resource_info(FILE* out, int bare, const game_driver* game)
 {
 	const char *start;
 
@@ -847,7 +869,8 @@ static void print_resource_info(FILE* out, const game_driver* game)
 		start = strrchr(game->source_file, '\\');
 	if (!start)
 		start = game->source_file - 1;
-	fprintf(out, " sourcefile=\"%s\"", normalize_string(start + 1));
+	if (!bare)
+		fprintf(out, " sourcefile=\"%s\"", normalize_string(start + 1));
 
 	fprintf(out, ">\n");
 
@@ -862,30 +885,31 @@ static void print_resource_info(FILE* out, const game_driver* game)
 		fprintf(out, "\t\t<manufacturer>%s</manufacturer>\n", normalize_string(game->manufacturer));
 
 	print_game_bios(out, game);
-	print_game_rom(out, game);
+	if (!bare)
+		print_game_rom(out, bare, game);
 	print_game_sample(out, game);
 
 	fprintf(out, "\t</" XML_TOP ">\n");
 }
 #endif
 
-static void print_mame_data(FILE* out, const game_driver* const games[])
+static void print_mame_data(FILE* out, int bare, const game_driver* const games[])
 {
 	int j;
 
 	/* print games */
 	for(j=0;games[j];++j)
-		print_game_info(out, games[j]);
+		print_game_info(out, bare, games[j]);
 
 #if !defined(MESS)
 	/* print resources */
  	for (j=0;games[j];++j)
- 		print_resource_info(out, games[j]);
+ 		print_resource_info(out, bare, games[j]);
 #endif
 }
 
 /* Print the MAME database in XML format */
-void print_mame_xml(FILE* out, const game_driver* const games[])
+void print_mame_xml(FILE* out, int bare, const game_driver* const games[])
 {
 	fprintf(out,
 		"<?xml version=\"1.0\"?>\n"
@@ -986,7 +1010,8 @@ void print_mame_xml(FILE* out, const game_driver* const games[])
 		normalize_string(build_version)
 	);
 
-	print_mame_data(out, games);
+	print_mame_data(out, bare, games);
 
 	fprintf(out, "</" XML_ROOT ">\n");
 }
+
