@@ -1,31 +1,51 @@
+/*
+    TODO:
+    - bonkadv_mcu_43: extract data from MCU (dumped eeprom data for now)
+    - bloodwar: verify all extracted data against real board (WIP)
+*/
+
 /***************************************************************************
 
     TOYBOX MCU data for Bonk's Adventure
 
 ***************************************************************************/
 
-// bonkadv_mcu_4_33 has 32 zeroed bytes every 64 bytes: it has been verified
-// that these zeroes are effectively written by the MCU
+// notes based on test programs results, verified on PCB:
+// - bonkadv_mcu_4_30 is the only cmd that ouputs an odd (655) number of bytes
+// - bonkadv_mcu_4_33: the 32 'zeroed' bytes every 64 bytes are effectively written by the MCU
 
-// MCU executed command: 0400 0E00 0034
+// MCU executed command: 4300 0100 - factory settings
+// this command is issued whenever the nvram settings are corrupted
+// the MCU writes directly to NVRAM
+static const UINT16 bonkadv_mcu_43[] = {
+	0x8BE0,0x8E71,0x0102,0x0102,0x0300,0x010C,0x0202,0x0202,
+	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
+	0x0030,0x0020,0x4F6B,0x0305,0x0000,0x0000,0x0000,0x0000,
+	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
+	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
+	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
+	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
+	0x0000,0x0000,0x0000,0x0082,0x6F82,0x628C,0xB490,0x6CAB
+};
+// MCU executed command: 0400 0E00 0034 - code
 /*
-200E00: 7071                     moveq   #$71, D0
-200E02: 7273                     moveq   #$73, D1
-200E04: 7475                     moveq   #$75, D2
-200E06: 7677                     moveq   #$77, D3
-200E08: 7879                     moveq   #$79, D4
-200E0A: 7A7B                     moveq   #$7b, D5
-200E0C: 7C7D                     moveq   #$7d, D6
-200E0E: 7E7F                     moveq   #$7f, D7
-200E10: 4E75                     rts
+200E00: 7071    moveq   #$71, D0
+200E02: 7273    moveq   #$73, D1
+200E04: 7475    moveq   #$75, D2
+200E06: 7677    moveq   #$77, D3
+200E08: 7879    moveq   #$79, D4
+200E0A: 7A7B    moveq   #$7b, D5
+200E0C: 7C7D    moveq   #$7d, D6
+200E0E: 7E7F    moveq   #$7f, D7
+200E10: 4E75    rts
 */
-static UINT16 bonkadv_mcu_4_34[] = {
+static const UINT16 bonkadv_mcu_4_34[] = {
 	0x7071,0x7273,0x7475,0x7677,0x7879,0x7a7b,0x7c7d,0x7e7f,
 	0x4e75
 };
 
 // MCU executed command: 0400 0180 0032 - 128 bytes at $200180
-static UINT16 bonkadv_mcu_4_32[] = {
+static const UINT16 bonkadv_mcu_4_32[] = {
 	0x00cc,0xcc0c,0xc0c0,0xc080,0x0484,0xb6a6,0x0404,0x80c0,
 	0x80b1,0xb1a1,0xa1b2,0xa2b3,0xb3a3,0xa3b1,0xb1b1,0xb1c0,
 	0xc0a1,0xa1a1,0xa1b2,0xb2a2,0xa290,0x9090,0xb9b9,0xa9a9,
@@ -35,22 +55,20 @@ static UINT16 bonkadv_mcu_4_32[] = {
 	0x9898,0xb1b1,0xa1a1,0xb2a2,0xb3b3,0xa3a3,0xb1b1,0xb1b1,
 	0xc0c0,0xa1a1,0xa1a1,0xb2b2,0xa2a2,0x9090,0x9000,0x0000
 };
-
-// MCU executed command: 0400 0280 0031 - 128 bytes at $200280
-static UINT16 bonkadv_mcu_4_31[] = {
+// MCU executed command: 0400 0280 0031 - 112 bytes at $200280
+static const UINT16 bonkadv_mcu_4_31[] = {
 	0x1013,0x1411,0x1216,0x1519,0x1a17,0x1824,0x2322,0x211f,
 	0x201e,0x1d1c,0x1b27,0x2825,0x2629,0x2a2b,0x2e2f,0x2c2d,
 	0x3130,0x3435,0x3233,0x3f3e,0x3d3c,0x3a3b,0x3938,0x3736,
 	0x4243,0x4041,0x4445,0x4649,0x4a47,0x484c,0x4b4f,0x504d,
 	0x4e5a,0x5958,0x5755,0x5654,0x5352,0x515d,0x5e5b,0x5c5f,
 	0x6061,0x6465,0x6263,0x6766,0x6a6b,0x6869,0x7574,0x7372,
-	0x7071,0x6f6e,0x6d6c,0x7879,0x7677,0x7a7b,0x7c7d,0x7e7f,
-	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000
+	0x7071,0x6f6e,0x6d6c,0x7879,0x7677,0x7a7b,0x7c7d,0x7e7f
 };
+// MCU executed command: 0400 0E50 0030 - 655 bytes at $200E50 (656 here)
+static const UINT16 bonkadv_mcu_4_30[] = {
 
-// MCU executed command: 0400 0E50 0030 - 688 bytes at $200E50
-static UINT16 bonkadv_mcu_4_30[] = {
-	0x8c00,0xa000,0x9700,0xa700,0xb200,0xb700,0xc000,0xcc00,
+	0x8c00,0x9700,0xa000,0xa700,0xb200,0xb700,0xc000,0xcc00,
 	0xd600,0xdf00,0xef00,0xf500,0xfd00,0x0501,0x0b01,0x1801,
 	0x1e01,0x2901,0x3101,0x3701,0x4101,0x4901,0x0b01,0x5d01,
 	0xa700,0xb200,0x6c01,0x8101,0xb200,0x8101,0x8101,0x8101,
@@ -92,13 +110,11 @@ static UINT16 bonkadv_mcu_4_30[] = {
 	0x1993,0xff00,0x0000,0x67ff,0x0000,0x0067,0xff00,0x0000,
 	0x27ff,0x0000,0x0390,0x8e23,0x978b,0xff00,0x0000,0x1d9e,
 	0xff00,0x0007,0x3bff,0x0000,0x001d,0xff00,0x0000,0x8e90,
-	0xff00,0x0005,0x2495,0x96ff,0x0000,0x009a,0xff00,0x0000,
-	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
-	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000
+	0xff00,0x0005,0x2495,0x96ff,0x0000,0x009a,0xff00,0x0000
 };
 
 // MCU executed command: 0400 0400 0033 - 2560 bytes at $200400
-static UINT16 bonkadv_mcu_4_33[] = {
+static const UINT16 bonkadv_mcu_4_33[] = {
 	0x00a4,0x0001,0x00a5,0x005a,0x00a6,0x0074,0x00a7,0x009b,
 	0x00a8,0x00d0,0x00a9,0x00fe,0x00aa,0x015d,0x00ab,0x01b0,
 	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
@@ -270,107 +286,3 @@ static UINT16 bonkadv_mcu_4_33[] = {
 	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000
 };
 
-// dynamic, per-level (29), in level order
-// PC=078896 : MCU executed command: 0400 0300 00xx - xx = subcmd
-static UINT16 bonkadv_mcu_4_00[] = { 0x0000,0x04C0,0x0000,0x0100,0x0600,0x0100 };
-static UINT16 bonkadv_mcu_4_02[] = { 0x0000,0x0760,0x0000,0x0100,0x0270,0x0100,0x0320,0x01B0,
-                                       0x0460,0x01B0,0x0510,0x0100,0x05E0,0x0100,0x0620,0x0120,
-                                       0x08A0,0x0120 };
-static UINT16 bonkadv_mcu_4_01[] = { 0x0000,0x0670,0x0000,0x0100,0x0200,0x0100,0x02E0,0x0090,
-                                       0x0400,0x0090,0x04E0,0x0100,0x07B0,0x0100 };
-static UINT16 bonkadv_mcu_4_05[] = { 0x0000,0x0610,0x0000,0x0100,0x0750,0x0100 };
-static UINT16 bonkadv_mcu_4_07[] = { 0x0000,0x03C0,0x0000,0x0100,0x0500,0x0100 };
-static UINT16 bonkadv_mcu_4_06[] = { 0x0000,0x05F0,0x0000,0x0100,0x0730,0x0100 };
-static UINT16 bonkadv_mcu_4_09[] = { 0x0000,0x05C0,0x0000,0x0100,0x0700,0x0100 };
-static UINT16 bonkadv_mcu_4_0D[] = { 0x0000,0x07A0,0x0000,0x0100,0x08E0,0x0100 };
-static UINT16 bonkadv_mcu_4_03[] = { 0x0000,0x0920,0x0000,0x0100,0x0A60,0x0100 };
-static UINT16 bonkadv_mcu_4_08[] = { 0x0000,0x0730,0x0000,0x0100,0x0870,0x0100 };
-static UINT16 bonkadv_mcu_4_04[] = { 0x0000,0x05C0,0x0000,0x0100,0x0200,0x0100,0x0280,0x00C0,
-                                       0x02E0,0x0060,0x03A0,0x0000,0x0700,0x0000 };
-static UINT16 bonkadv_mcu_4_0C[] = { 0x0000,0x06E0,0x0000,0x0100,0x0820,0x0100 };
-static UINT16 bonkadv_mcu_4_0A[] = { 0x0000,0x05A0,0x0000,0x0100,0x06E0,0x0100 };
-static UINT16 bonkadv_mcu_4_0B[] = { 0x0000,0x0470,0x0000,0x0100,0x05B0,0x0100 };
-static UINT16 bonkadv_mcu_4_10[] = { 0x0000,0x06C0,0x0000,0x0100,0x03B0,0x0100,0x0460,0x0050,
-                                       0x05E0,0x0050,0x0650,0xFFE0,0x0800,0xFFE0 };
-static UINT16 bonkadv_mcu_4_0E[] = { 0x0000,0x0630,0x0000,0x0100,0x0770,0x0100 };
-static UINT16 bonkadv_mcu_4_13[] = { 0x0000,0x05C0,0x0000,0x0100,0x0700,0x0100 };
-static UINT16 bonkadv_mcu_4_0F[] = { 0x0000,0x05C0,0x0000,0x0100,0x0700,0x0100 };
-static UINT16 bonkadv_mcu_4_11[] = { 0x0000,0x05C0,0x0000,0x0100,0x0700,0x0100 };
-static UINT16 bonkadv_mcu_4_14[] = { 0x0000,0x05C0,0x0000,0x0100,0x0700,0x0100 };
-static UINT16 bonkadv_mcu_4_12[] = { 0x0000,0x05C0,0x0000,0x0100,0x0700,0x0100 };
-static UINT16 bonkadv_mcu_4_17[] = { 0x0000,0x0520,0x0000,0x0100,0x0660,0x0100 };
-static UINT16 bonkadv_mcu_4_1A[] = { 0x0000,0x03C0,0x0000,0x0100,0x0500,0x0100 };
-static UINT16 bonkadv_mcu_4_15[] = { 0x0000,0x02C0,0x0000,0x0100,0x0400,0x0100 };
-static UINT16 bonkadv_mcu_4_18[] = { 0x0000,0x03C0,0x0000,0x0100,0x0500,0x0100 };
-static UINT16 bonkadv_mcu_4_16[] = { 0x0000,0x02F0,0x0000,0x0100,0x0430,0x0100 };
-static UINT16 bonkadv_mcu_4_19[] = { 0x0000,0x03A0,0x0000,0x0100,0x04E0,0x0100 };
-static UINT16 bonkadv_mcu_4_1B[] = { 0x0000,0x0460,0x0000,0x0100,0x05A0,0x0100 };
-static UINT16 bonkadv_mcu_4_1C[] = { 0x0000,0x02C0,0x0000,0x0100,0x0400,0x0100 };
-
-
-/***************************************************************************
-
-    TOYBOX MCU data for Blood Warrior
-
-***************************************************************************/
-
-// --- unknown data ---
-static UINT16 bloodwar_mcu_4_01[] = {0x0000}; // Warrior 1
-static UINT16 bloodwar_mcu_4_02[] = {0x0000}; // Warrior 2
-static UINT16 bloodwar_mcu_4_03[] = {0x0000}; // Warrior 3
-static UINT16 bloodwar_mcu_4_04[] = {0x0000}; // Warrior 4
-static UINT16 bloodwar_mcu_4_05[] = {0x0000}; // Warrior 5
-static UINT16 bloodwar_mcu_4_06[] = {0x0000}; // Warrior 6
-static UINT16 bloodwar_mcu_4_07[] = {0x0000}; // Warrior 7
-static UINT16 bloodwar_mcu_4_08[] = {0x0000}; // Warrior 8
-static UINT16 bloodwar_mcu_4_09[] = {0x0000}; // Warrior 9
-
-
-// --- palette data ---
-//  number of palettes (>=1)
-//  palette data follows (each palette is 0x200 bytes long)
-//  a negative word will end the palette
-static UINT16 bloodwar_mcu_4_0a[] = {0x0001,0x8000}; // Warrior 1 Player 1
-static UINT16 bloodwar_mcu_4_0b[] = {0x0001,0x8000}; // Warrior 1 Player 2
-static UINT16 bloodwar_mcu_4_0c[] = {0x0001,0x8000}; // Warrior 5 Player 1
-static UINT16 bloodwar_mcu_4_0d[] = {0x0001,0x8000}; // Warrior 5 Player 2
-static UINT16 bloodwar_mcu_4_0e[] = {0x0001,0x8000}; // Warrior 4 Player 2
-static UINT16 bloodwar_mcu_4_0f[] = {0x0001,0x8000}; // Warrior 4 Player 1
-static UINT16 bloodwar_mcu_4_10[] = {0x0001,0x8000}; // Warrior 6 Player 1
-static UINT16 bloodwar_mcu_4_11[] = {0x0001,0x8000}; // Warrior 6 Player 2
-static UINT16 bloodwar_mcu_4_12[] = {0x0001,0x8000}; // Warrior 9 Player 1
-static UINT16 bloodwar_mcu_4_13[] = {0x0001,0x8000}; // Warrior 9 Player 2
-static UINT16 bloodwar_mcu_4_14[] = {0x0001,0x8000}; // Warrior 7 Player 1
-static UINT16 bloodwar_mcu_4_15[] = {0x0001,0x8000}; // Warrior 7 Player 2
-static UINT16 bloodwar_mcu_4_16[] = {0x0001,0x8000}; // Warrior 8 Player 1
-static UINT16 bloodwar_mcu_4_17[] = {0x0001,0x8000}; // Warrior 8 Player 2
-static UINT16 bloodwar_mcu_4_18[] = {0x0001,0x8000}; // Warrior 2 Player 2
-static UINT16 bloodwar_mcu_4_19[] = {0x0001,0x8000}; // Warrior 2 Player 1
-static UINT16 bloodwar_mcu_4_1a[] = {0x0001,0x8000}; // Warrior 3 Player 1
-static UINT16 bloodwar_mcu_4_1b[] = {0x0001,0x8000}; // Warrior 3 Player 2
-
-
-// --- tilemap data ---
-//  tile data (ff means no tiles) followed by routine index
-static UINT16 bloodwar_mcu_4_1c[] = {0xff00}; // Warrior 8
-static UINT16 bloodwar_mcu_4_1d[] = {0xff00}; // Warrior 2
-static UINT16 bloodwar_mcu_4_1e[] = {0xff00}; // Warrior 3
-static UINT16 bloodwar_mcu_4_1f[] = {0xff00}; // Warrior 5
-static UINT16 bloodwar_mcu_4_20[] = {0xff00}; // Warrior 4
-static UINT16 bloodwar_mcu_4_21[] = {0xff00}; // Warrior 6
-static UINT16 bloodwar_mcu_4_22[] = {0xff00}; // Warrior 1
-static UINT16 bloodwar_mcu_4_23[] = {0xff00}; // Warrior 9
-static UINT16 bloodwar_mcu_4_24[] = {0xff00}; // Warrior 7
-
-
-// --- fighter data: pointers to ROM data ---
-static UINT16 bloodwar_mcu_4_25[] = {0x0000,0x0000}; // Warrior 1
-static UINT16 bloodwar_mcu_4_26[] = {0x0000,0x0000}; // Warrior 2
-static UINT16 bloodwar_mcu_4_27[] = {0x0000,0x0000}; // Warrior 3
-static UINT16 bloodwar_mcu_4_28[] = {0x0000,0x0000}; // Warrior 4
-static UINT16 bloodwar_mcu_4_29[] = {0x0000,0x0000}; // Warrior 5
-static UINT16 bloodwar_mcu_4_2a[] = {0x0000,0x0000}; // Warrior 6
-static UINT16 bloodwar_mcu_4_2b[] = {0x0000,0x0000}; // Warrior 7
-static UINT16 bloodwar_mcu_4_2c[] = {0x0000,0x0000}; // Warrior 8
-static UINT16 bloodwar_mcu_4_2d[] = {0x0000,0x0000}; // Warrior 9
-
