@@ -146,6 +146,8 @@ Pipi & Bibis     | Fix Eight        | V-Five           | Snow Bros. 2     |
 
 #include "driver.h"
 #include "cpu/m68000/m68000.h"
+#include "toaplan2.h"
+#include "sound/samples.h"
 
 
 
@@ -1477,6 +1479,84 @@ static void mark_tile_priority(int controller)
 #endif
 }
 
+
+static void thunder_taisaku(void)
+{
+	if (thunder1 == 1)
+	{
+		thunder2 = input_port_1_word_r(0,0);
+		thunder3 = thunder2 & 0x10;
+		
+		if (thunder3 != 0x10 || sample_playing(7))
+		{
+			sample_stop (5);
+		}
+	}
+	
+	if (thunder4 == 1)
+	{
+		thunder5 = input_port_2_word_r(0,0);
+		thunder6 = thunder5 & 0x10;
+		
+		if (thunder6 != 0x10 || sample_playing(7))
+		{
+			sample_stop (6);
+		}
+	}
+}
+
+
+static void ese_fadeout(void)
+{
+	if (fadeout_stop == 1)
+	{
+		playing2 = 0xff;
+		fadeout_ready = 0;
+		fadeout_stop = 0;
+		sample_vol1 = 1.00;
+		sample_set_volume (0, 1.00);
+	}
+	
+	if (counter1 >= 20)
+	{
+		counter1 = 0;
+		if (fadeout_ready == 1)
+		{
+			sample_vol1 = sample_vol1 - 0.10;
+			if (sample_vol1 <= 0)
+			{
+				sample_vol1 = 0;
+			}
+			sample_set_volume (0, sample_vol1);
+		}
+		if (sample_vol1 == 0)
+		{
+			sample_stop (0);
+			fadeout_ready = 0;
+			fadeout_stop = 0;
+			sample_vol1 = 1.00;
+			sample_set_volume (0, 1.00);
+			if (playing2 != 0xff)
+			{
+			sample_start (0, playing2 , 1);
+			playing1 = 0xff;
+			playing2 = 0xff;
+			}
+		}
+	}
+	counter1++;
+}
+
+static UINT16 tag_to_word_r(const char *tag)
+{
+	if(port_tag_to_index(tag) != -1)
+	{
+		return port_tag_to_handler16(tag)(0,0);
+	}else{
+		return 0;	
+	}
+}
+
 /***************************************************************************
     Draw the game screen in the given mame_bitmap.
 ***************************************************************************/
@@ -1490,6 +1570,12 @@ VIDEO_UPDATE( toaplan2_0 )
 	toaplan2_log_vram();
 #endif
 
+	if(tag_to_word_r("EXTR") & 0x1){
+		spriteram16_n[0] = spriteram16_now[0];
+	}else{
+		spriteram16_n[0] = spriteram16_new[0];
+	}
+
 	mark_sprite_priority(0);
 	mark_tile_priority(0);
 
@@ -1505,6 +1591,37 @@ VIDEO_UPDATE( toaplan2_0 )
 	}
 }
 
+VIDEO_UPDATE( toaplan2_1 )
+{
+	int priority;
+
+
+#ifdef MAME_DEBUG
+	toaplan2_log_vram();
+#endif
+
+	if(tag_to_word_r("EXTR") & 0x1){
+		spriteram16_n[0] = spriteram16_now[0];
+	}else{
+		spriteram16_n[0] = spriteram16_new[0];
+	}
+
+	mark_sprite_priority(0);
+	mark_tile_priority(0);
+
+	fillbitmap(bitmap,Machine->pens[0],cliprect);
+
+	for (priority = 0; priority < 16; priority++)
+	{
+		if (bg_tile_priority[0][priority]) tilemap_draw(bitmap,cliprect,bg_tilemap[0],priority,0);
+		if (fg_tile_priority[0][priority]) tilemap_draw(bitmap,cliprect,fg_tilemap[0],priority,0);
+		if (top_tile_priority[0][priority]) tilemap_draw(bitmap,cliprect,top_tilemap[0],priority,0);
+		if (sprite_priority[0][priority])
+			draw_sprites(bitmap,cliprect,0,priority,0);
+	}
+	ese_fadeout();
+}
+
 VIDEO_UPDATE( dogyuun_1 )
 {
 	int priority;
@@ -1514,6 +1631,14 @@ VIDEO_UPDATE( dogyuun_1 )
 	toaplan2_log_vram();
 #endif
 
+	if(tag_to_word_r("EXTR") & 0x1){
+		spriteram16_n[0] = spriteram16_now[0];
+		spriteram16_n[1] = spriteram16_now[1];
+	}else{
+		spriteram16_n[0] = spriteram16_new[0];
+		spriteram16_n[1] = spriteram16_new[1];
+	}
+
 	mark_sprite_priority(0);
 	mark_sprite_priority(1);
 	mark_tile_priority(0);
@@ -1537,42 +1662,106 @@ VIDEO_UPDATE( dogyuun_1 )
 		if (sprite_priority[0][priority])
 			draw_sprites(bitmap,cliprect,0,priority,0);
 	}
+	thunder_taisaku();
 }
 
 VIDEO_UPDATE( batsugun_1 )
 {
 	int priority;
-
+	static int bg1=0,fg1=0,tp1=0,tp0=0;
+	UINT32 *vramp;
+	static int bg[2]={0,0},fg[2]={0,0},top[2]={0,0};
 
 #ifdef MAME_DEBUG
 	toaplan2_log_vram();
 #endif
 
+	if(tag_to_word_r("EXTR") & 0x1){
+		spriteram16_n[0] = spriteram16_now[0];
+		spriteram16_n[1] = spriteram16_now[1];
+	}else{
+		spriteram16_n[0] = spriteram16_new[0];
+		spriteram16_n[1] = spriteram16_new[1];
+	}
+
 	mark_sprite_priority(0);
 	mark_sprite_priority(1);
 	mark_tile_priority(0);
 	mark_tile_priority(1);
 
+	bg[0]=0;fg[0]=0;top[0]=0;
+	bg[1]=0;fg[1]=0;top[1]=0;
+
+	for (priority = 0; priority < 16; priority++)
+	{
+		if (bg_tile_priority[0][priority]) bg[0]++;
+		if (fg_tile_priority[0][priority]) fg[0]++;
+		if (top_tile_priority[0][priority]) top[0]++;
+		if (bg_tile_priority[1][priority]) bg[1]++;
+		if (fg_tile_priority[1][priority]) fg[1]++;
+		if (top_tile_priority[1][priority]) top[1]++;
+	}
+
+	if( (bg[0]==1 && bg[1]==1 && fg[0]==1 && fg[1]==1 && top[0]==1 && top[1]==1)||
+		(bg[0]==1 && bg[1]==2 && fg[0]==1 && fg[1]==1 && top[0]==1 && top[1]==1)||
+		(bg[0]==1 && bg[1]==2 && fg[0]==1 && fg[1]==2 && top[0]==1 && top[1]==1)){
+		tp1=1;
+	} else {
+		tp1=0;
+	}
+
 	fillbitmap(bitmap,Machine->pens[0],cliprect);
 
-	for (priority = 0; priority < 16; priority++)
+	vramp = (UINT32*)bgvideoram16[1];
+	if(*(vramp+28)==0x225e027a){
+		bg1=0;
+		fg1=1;
+	} else if(*(vramp+28)==0x0aa50060){
+		bg1=2;
+		fg1=1;
+	} else if(*(vramp+28)==0x02040032){
+		bg1=1;
+		fg1=2;
+	} else {
+		bg1=1;
+		fg1=1;
+	}
+
+	vramp = (UINT32*)fgvideoram16[1];
+	if(*vramp==0x09cb006d||*vramp==0x09ab006d||*vramp==0x01c4006e)
 	{
-		if (bg_tile_priority[1][priority]) tilemap_draw(bitmap,cliprect,bg_tilemap[1],priority,0);/* 2 */
-		if (bg_tile_priority[0][priority]) tilemap_draw(bitmap,cliprect,bg_tilemap[0],priority,0);
-		if (fg_tile_priority[0][priority]) tilemap_draw(bitmap,cliprect,fg_tilemap[0],priority,0);
-		if (fg_tile_priority[1][priority]) tilemap_draw(bitmap,cliprect,fg_tilemap[1],priority,0);
-		if (top_tile_priority[0][priority]) tilemap_draw(bitmap,cliprect,top_tilemap[0],priority,0);
-		if (sprite_priority[0][priority])
-			draw_sprites(bitmap,cliprect,0,priority,0);
+		fg1=3;
+	}
+
+	vramp = (UINT32*)topvideoram16[0];
+	if(*vramp==0x2500740)
+	{
+		tp0=1;
+	} else {
+		tp0=0;
 	}
 
 	for (priority = 0; priority < 16; priority++)
 	{
-		if (top_tile_priority[1][priority]) tilemap_draw(bitmap,cliprect,top_tilemap[1],priority,0);
-		if (sprite_priority[1][priority])
-			draw_sprites(bitmap,cliprect,1,priority,0);
+		if (top_tile_priority[1][priority] && tp1==1) tilemap_draw(bitmap,cliprect,top_tilemap[1],priority,0);  /* 3 */
+		if (bg_tile_priority[1][priority] && bg1==2) tilemap_draw(bitmap,cliprect,bg_tilemap[1],priority,0);    /* 5 */
+		if (fg_tile_priority[1][priority] && fg1==3) tilemap_draw(bitmap,cliprect,fg_tilemap[1],priority,0);    /* 4 */
+		if (bg_tile_priority[0][priority]) tilemap_draw(bitmap,cliprect,bg_tilemap[0],priority,0);				/* 2 */
+		if (fg_tile_priority[0][priority]) tilemap_draw(bitmap,cliprect,fg_tilemap[0],priority,0);				/* 1 */
+		if (bg_tile_priority[1][priority] && bg1==1) tilemap_draw(bitmap,cliprect,bg_tilemap[1],priority,0);    /* 5 */
+		if (fg_tile_priority[1][priority] && fg1==1) tilemap_draw(bitmap,cliprect,fg_tilemap[1],priority,0);    /* 4 */
+		if (top_tile_priority[0][priority]) tilemap_draw(bitmap,cliprect,top_tilemap[0],priority,0);			/* 0 */
+		if (sprite_priority[0][priority]) draw_sprites(bitmap,cliprect,0,priority,0);
 	}
 
+	for (priority = 0; priority < 16; priority++)
+	{
+		if (fg_tile_priority[1][priority] && fg1==2) tilemap_draw(bitmap,cliprect,fg_tilemap[1],priority,0);    /* 4 */
+		if (top_tile_priority[1][priority] && tp1==0) tilemap_draw(bitmap,cliprect,top_tilemap[1],priority,0);  /* 3 */
+		if (sprite_priority[1][priority]) draw_sprites(bitmap,cliprect,1,priority,0);
+		if (bg_tile_priority[1][priority] && tp1==1) tilemap_draw(bitmap,cliprect,bg_tilemap[1],priority,0);    /* 5 */
+		if (sprite_priority[0][priority] && tp0==1) draw_sprites(bitmap,cliprect,0,priority,0);
+	}
 }
 
 VIDEO_UPDATE( truxton2_0 )
@@ -1639,6 +1828,12 @@ VIDEO_UPDATE( mahoudai_0 )
 	toaplan2_log_vram();
 #endif
 
+	if(tag_to_word_r("EXTR") & 0x1){
+		spriteram16_n[0] = spriteram16_now[0];
+	}else{
+		spriteram16_n[0] = spriteram16_new[0];
+	}
+
 	mark_sprite_priority(0);
 	mark_tile_priority(0);
 
